@@ -20,22 +20,54 @@
  *        Vlad Grecescu (b100dian@gmail.com)
  */
 
-#include "GtkamlAttribute.h"
+#include <glib.h>
+#include <glib-object.h>
+#include <stdlib.h>
+#include <string.h>
+#include <vala.h>
 
 
+#define GTKAML_TYPE_ATTRIBUTE (gtkaml_attribute_get_type ())
+#define GTKAML_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_ATTRIBUTE, GtkamlAttribute))
+#define GTKAML_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_ATTRIBUTE, GtkamlAttributeClass))
+#define GTKAML_IS_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_ATTRIBUTE))
+#define GTKAML_IS_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_ATTRIBUTE))
+#define GTKAML_ATTRIBUTE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_ATTRIBUTE, GtkamlAttributeClass))
 
+typedef struct _GtkamlAttribute GtkamlAttribute;
+typedef struct _GtkamlAttributeClass GtkamlAttributeClass;
+typedef struct _GtkamlAttributePrivate GtkamlAttributePrivate;
+
+/**
+ * A generic xml attribute with a name and a reflected Vala type
+ */
+struct _GtkamlAttribute {
+	GObject parent_instance;
+	GtkamlAttributePrivate * priv;
+};
+
+struct _GtkamlAttributeClass {
+	GObjectClass parent_class;
+};
 
 struct _GtkamlAttributePrivate {
 	char* _name;
 	ValaSymbol* _target_type;
 };
 
+
+
+GType gtkaml_attribute_get_type (void);
 #define GTKAML_ATTRIBUTE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GTKAML_TYPE_ATTRIBUTE, GtkamlAttributePrivate))
 enum  {
 	GTKAML_ATTRIBUTE_DUMMY_PROPERTY,
 	GTKAML_ATTRIBUTE_NAME,
 	GTKAML_ATTRIBUTE_TARGET_TYPE
 };
+const char* gtkaml_attribute_get_name (GtkamlAttribute* self);
+void gtkaml_attribute_set_name (GtkamlAttribute* self, const char* value);
+ValaSymbol* gtkaml_attribute_get_target_type (GtkamlAttribute* self);
+void gtkaml_attribute_set_target_type (GtkamlAttribute* self, ValaSymbol* value);
 static gpointer gtkaml_attribute_parent_class = NULL;
 static void gtkaml_attribute_finalize (GObject* obj);
 
