@@ -20,13 +20,83 @@
  *        Vlad Grecescu (b100dian@gmail.com)
  */
 
-#include "GtkamlClassDefinition.h"
-#include <gee/arraylist.h>
-#include <gee/collection.h>
-#include <vala/valasymbol.h>
+#include <glib.h>
+#include <glib-object.h>
+#include <vala.h>
+#include <stdlib.h>
+#include <string.h>
+#include <gee.h>
 
 
+#define TYPE_DEFINITION_SCOPE (definition_scope_get_type ())
 
+#define GTKAML_TYPE_CLASS_DEFINITION (gtkaml_class_definition_get_type ())
+#define GTKAML_CLASS_DEFINITION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_CLASS_DEFINITION, GtkamlClassDefinition))
+#define GTKAML_CLASS_DEFINITION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_CLASS_DEFINITION, GtkamlClassDefinitionClass))
+#define GTKAML_IS_CLASS_DEFINITION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_CLASS_DEFINITION))
+#define GTKAML_IS_CLASS_DEFINITION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_CLASS_DEFINITION))
+#define GTKAML_CLASS_DEFINITION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_CLASS_DEFINITION, GtkamlClassDefinitionClass))
+
+typedef struct _GtkamlClassDefinition GtkamlClassDefinition;
+typedef struct _GtkamlClassDefinitionClass GtkamlClassDefinitionClass;
+typedef struct _GtkamlClassDefinitionPrivate GtkamlClassDefinitionPrivate;
+
+#define GTKAML_TYPE_ATTRIBUTE (gtkaml_attribute_get_type ())
+#define GTKAML_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_ATTRIBUTE, GtkamlAttribute))
+#define GTKAML_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_ATTRIBUTE, GtkamlAttributeClass))
+#define GTKAML_IS_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_ATTRIBUTE))
+#define GTKAML_IS_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_ATTRIBUTE))
+#define GTKAML_ATTRIBUTE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_ATTRIBUTE, GtkamlAttributeClass))
+
+typedef struct _GtkamlAttribute GtkamlAttribute;
+typedef struct _GtkamlAttributeClass GtkamlAttributeClass;
+
+#define GTKAML_TYPE_METHOD (gtkaml_method_get_type ())
+#define GTKAML_METHOD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_METHOD, GtkamlMethod))
+#define GTKAML_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_METHOD, GtkamlMethodClass))
+#define GTKAML_IS_METHOD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_METHOD))
+#define GTKAML_IS_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_METHOD))
+#define GTKAML_METHOD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_METHOD, GtkamlMethodClass))
+
+typedef struct _GtkamlMethod GtkamlMethod;
+typedef struct _GtkamlMethodClass GtkamlMethodClass;
+
+#define GTKAML_TYPE_CONSTRUCT_METHOD (gtkaml_construct_method_get_type ())
+#define GTKAML_CONSTRUCT_METHOD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_CONSTRUCT_METHOD, GtkamlConstructMethod))
+#define GTKAML_CONSTRUCT_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_CONSTRUCT_METHOD, GtkamlConstructMethodClass))
+#define GTKAML_IS_CONSTRUCT_METHOD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_CONSTRUCT_METHOD))
+#define GTKAML_IS_CONSTRUCT_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_CONSTRUCT_METHOD))
+#define GTKAML_CONSTRUCT_METHOD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_CONSTRUCT_METHOD, GtkamlConstructMethodClass))
+
+typedef struct _GtkamlConstructMethod GtkamlConstructMethod;
+typedef struct _GtkamlConstructMethodClass GtkamlConstructMethodClass;
+
+#define GTKAML_TYPE_ADD_METHOD (gtkaml_add_method_get_type ())
+#define GTKAML_ADD_METHOD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_ADD_METHOD, GtkamlAddMethod))
+#define GTKAML_ADD_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_ADD_METHOD, GtkamlAddMethodClass))
+#define GTKAML_IS_ADD_METHOD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_ADD_METHOD))
+#define GTKAML_IS_ADD_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_ADD_METHOD))
+#define GTKAML_ADD_METHOD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_ADD_METHOD, GtkamlAddMethodClass))
+
+typedef struct _GtkamlAddMethod GtkamlAddMethod;
+typedef struct _GtkamlAddMethodClass GtkamlAddMethodClass;
+
+typedef enum  {
+	DEFINITION_SCOPE_MAIN_CLASS = 0,
+	DEFINITION_SCOPE_PUBLIC,
+	DEFINITION_SCOPE_PRIVATE,
+	DEFINITION_SCOPE_CONSTRUCTOR
+} DefinitionScope;
+
+/** represents a gtkaml tag */
+struct _GtkamlClassDefinition {
+	GObject parent_instance;
+	GtkamlClassDefinitionPrivate * priv;
+};
+
+struct _GtkamlClassDefinitionClass {
+	GObjectClass parent_class;
+};
 
 struct _GtkamlClassDefinitionPrivate {
 	ValaSourceReference* _source_reference;
@@ -43,6 +113,14 @@ struct _GtkamlClassDefinitionPrivate {
 	char* _preconstruct_code;
 };
 
+
+
+GType definition_scope_get_type (void);
+GType gtkaml_class_definition_get_type (void);
+GType gtkaml_attribute_get_type (void);
+GType gtkaml_method_get_type (void);
+GType gtkaml_construct_method_get_type (void);
+GType gtkaml_add_method_get_type (void);
 #define GTKAML_CLASS_DEFINITION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GTKAML_TYPE_CLASS_DEFINITION, GtkamlClassDefinitionPrivate))
 enum  {
 	GTKAML_CLASS_DEFINITION_DUMMY_PROPERTY,
@@ -60,6 +138,36 @@ enum  {
 	GTKAML_CLASS_DEFINITION_CONSTRUCT_CODE,
 	GTKAML_CLASS_DEFINITION_PRECONSTRUCT_CODE
 };
+void gtkaml_class_definition_set_source_reference (GtkamlClassDefinition* self, ValaSourceReference* value);
+void gtkaml_class_definition_set_base_ns (GtkamlClassDefinition* self, const char* value);
+void gtkaml_class_definition_set_identifier (GtkamlClassDefinition* self, const char* value);
+void gtkaml_class_definition_set_base_type (GtkamlClassDefinition* self, ValaClass* value);
+void gtkaml_class_definition_set_definition_scope (GtkamlClassDefinition* self, DefinitionScope value);
+void gtkaml_class_definition_set_parent_container (GtkamlClassDefinition* self, GtkamlClassDefinition* value);
+void gtkaml_class_definition_set_attrs (GtkamlClassDefinition* self, GeeList* value);
+void gtkaml_class_definition_set_construct_method (GtkamlClassDefinition* self, GtkamlConstructMethod* value);
+void gtkaml_class_definition_set_children (GtkamlClassDefinition* self, GeeList* value);
+void gtkaml_class_definition_set_construct_code (GtkamlClassDefinition* self, const char* value);
+void gtkaml_class_definition_set_preconstruct_code (GtkamlClassDefinition* self, const char* value);
+GtkamlClassDefinition* gtkaml_class_definition_new (ValaSourceReference* source_reference, const char* identifier, const char* base_ns, ValaClass* base_type, DefinitionScope definition_scope, GtkamlClassDefinition* parent_container);
+GtkamlClassDefinition* gtkaml_class_definition_construct (GType object_type, ValaSourceReference* source_reference, const char* identifier, const char* base_ns, ValaClass* base_type, DefinitionScope definition_scope, GtkamlClassDefinition* parent_container);
+GtkamlClassDefinition* gtkaml_class_definition_new (ValaSourceReference* source_reference, const char* identifier, const char* base_ns, ValaClass* base_type, DefinitionScope definition_scope, GtkamlClassDefinition* parent_container);
+GeeList* gtkaml_class_definition_get_attrs (GtkamlClassDefinition* self);
+void gtkaml_class_definition_add_attribute (GtkamlClassDefinition* self, GtkamlAttribute* attr);
+GeeList* gtkaml_class_definition_get_children (GtkamlClassDefinition* self);
+void gtkaml_class_definition_add_child (GtkamlClassDefinition* self, GtkamlClassDefinition* child);
+ValaSourceReference* gtkaml_class_definition_get_source_reference (GtkamlClassDefinition* self);
+const char* gtkaml_class_definition_get_identifier (GtkamlClassDefinition* self);
+const char* gtkaml_class_definition_get_base_ns (GtkamlClassDefinition* self);
+ValaClass* gtkaml_class_definition_get_base_type (GtkamlClassDefinition* self);
+char* gtkaml_class_definition_get_base_full_name (GtkamlClassDefinition* self);
+GtkamlClassDefinition* gtkaml_class_definition_get_parent_container (GtkamlClassDefinition* self);
+DefinitionScope gtkaml_class_definition_get_definition_scope (GtkamlClassDefinition* self);
+GtkamlConstructMethod* gtkaml_class_definition_get_construct_method (GtkamlClassDefinition* self);
+GtkamlAddMethod* gtkaml_class_definition_get_add_method (GtkamlClassDefinition* self);
+void gtkaml_class_definition_set_add_method (GtkamlClassDefinition* self, GtkamlAddMethod* value);
+const char* gtkaml_class_definition_get_construct_code (GtkamlClassDefinition* self);
+const char* gtkaml_class_definition_get_preconstruct_code (GtkamlClassDefinition* self);
 static gpointer gtkaml_class_definition_parent_class = NULL;
 static void gtkaml_class_definition_finalize (GObject* obj);
 
