@@ -20,31 +20,129 @@
  *        Vlad Grecescu (b100dian@gmail.com)
  */
 
-#include "GtkamlCodeGenerator.h"
-#include <gee/map.h>
-#include <gee/iterable.h>
-#include <gee/iterator.h>
-#include <vala/valasymbol.h>
-#include <vala/valareport.h>
-#include <vala/valasourcereference.h>
-#include <vala/valadatatype.h>
-#include <vala/valafield.h>
-#include <vala/valaproperty.h>
-#include <vala/valaformalparameter.h>
-#include <vala/valaunresolvedtype.h>
-#include <vala/valasignal.h>
-#include <gee/list.h>
-#include <gee/collection.h>
-#include "GtkamlMethod.h"
-#include "GtkamlComplexAttribute.h"
-#include "GtkamlSimpleAttribute.h"
-#include "GtkamlReferenceClassDefinition.h"
+#include <glib.h>
+#include <glib-object.h>
+#include <stdlib.h>
 #include <string.h>
+#include <vala.h>
+#include <gee.h>
 
 
+#define GTKAML_TYPE_CODE_GENERATOR (gtkaml_code_generator_get_type ())
+#define GTKAML_CODE_GENERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_CODE_GENERATOR, GtkamlCodeGenerator))
+#define GTKAML_CODE_GENERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_CODE_GENERATOR, GtkamlCodeGeneratorClass))
+#define GTKAML_IS_CODE_GENERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_CODE_GENERATOR))
+#define GTKAML_IS_CODE_GENERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_CODE_GENERATOR))
+#define GTKAML_CODE_GENERATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_CODE_GENERATOR, GtkamlCodeGeneratorClass))
 
+typedef struct _GtkamlCodeGenerator GtkamlCodeGenerator;
+typedef struct _GtkamlCodeGeneratorClass GtkamlCodeGeneratorClass;
+typedef struct _GtkamlCodeGeneratorPrivate GtkamlCodeGeneratorPrivate;
+
+#define GTKAML_TYPE_CLASS_DEFINITION (gtkaml_class_definition_get_type ())
+#define GTKAML_CLASS_DEFINITION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_CLASS_DEFINITION, GtkamlClassDefinition))
+#define GTKAML_CLASS_DEFINITION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_CLASS_DEFINITION, GtkamlClassDefinitionClass))
+#define GTKAML_IS_CLASS_DEFINITION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_CLASS_DEFINITION))
+#define GTKAML_IS_CLASS_DEFINITION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_CLASS_DEFINITION))
+#define GTKAML_CLASS_DEFINITION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_CLASS_DEFINITION, GtkamlClassDefinitionClass))
+
+typedef struct _GtkamlClassDefinition GtkamlClassDefinition;
+typedef struct _GtkamlClassDefinitionClass GtkamlClassDefinitionClass;
+
+#define GTKAML_TYPE_ROOT_CLASS_DEFINITION (gtkaml_root_class_definition_get_type ())
+#define GTKAML_ROOT_CLASS_DEFINITION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_ROOT_CLASS_DEFINITION, GtkamlRootClassDefinition))
+#define GTKAML_ROOT_CLASS_DEFINITION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_ROOT_CLASS_DEFINITION, GtkamlRootClassDefinitionClass))
+#define GTKAML_IS_ROOT_CLASS_DEFINITION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_ROOT_CLASS_DEFINITION))
+#define GTKAML_IS_ROOT_CLASS_DEFINITION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_ROOT_CLASS_DEFINITION))
+#define GTKAML_ROOT_CLASS_DEFINITION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_ROOT_CLASS_DEFINITION, GtkamlRootClassDefinitionClass))
+
+typedef struct _GtkamlRootClassDefinition GtkamlRootClassDefinition;
+typedef struct _GtkamlRootClassDefinitionClass GtkamlRootClassDefinitionClass;
+
+#define GTKAML_TYPE_REFERENCE_CLASS_DEFINITION (gtkaml_reference_class_definition_get_type ())
+#define GTKAML_REFERENCE_CLASS_DEFINITION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_REFERENCE_CLASS_DEFINITION, GtkamlReferenceClassDefinition))
+#define GTKAML_REFERENCE_CLASS_DEFINITION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_REFERENCE_CLASS_DEFINITION, GtkamlReferenceClassDefinitionClass))
+#define GTKAML_IS_REFERENCE_CLASS_DEFINITION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_REFERENCE_CLASS_DEFINITION))
+#define GTKAML_IS_REFERENCE_CLASS_DEFINITION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_REFERENCE_CLASS_DEFINITION))
+#define GTKAML_REFERENCE_CLASS_DEFINITION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_REFERENCE_CLASS_DEFINITION, GtkamlReferenceClassDefinitionClass))
+
+typedef struct _GtkamlReferenceClassDefinition GtkamlReferenceClassDefinition;
+typedef struct _GtkamlReferenceClassDefinitionClass GtkamlReferenceClassDefinitionClass;
+
+#define GTKAML_TYPE_ATTRIBUTE (gtkaml_attribute_get_type ())
+#define GTKAML_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_ATTRIBUTE, GtkamlAttribute))
+#define GTKAML_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_ATTRIBUTE, GtkamlAttributeClass))
+#define GTKAML_IS_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_ATTRIBUTE))
+#define GTKAML_IS_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_ATTRIBUTE))
+#define GTKAML_ATTRIBUTE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_ATTRIBUTE, GtkamlAttributeClass))
+
+typedef struct _GtkamlAttribute GtkamlAttribute;
+typedef struct _GtkamlAttributeClass GtkamlAttributeClass;
+
+#define GTKAML_TYPE_COMPLEX_ATTRIBUTE (gtkaml_complex_attribute_get_type ())
+#define GTKAML_COMPLEX_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_COMPLEX_ATTRIBUTE, GtkamlComplexAttribute))
+#define GTKAML_COMPLEX_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_COMPLEX_ATTRIBUTE, GtkamlComplexAttributeClass))
+#define GTKAML_IS_COMPLEX_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_COMPLEX_ATTRIBUTE))
+#define GTKAML_IS_COMPLEX_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_COMPLEX_ATTRIBUTE))
+#define GTKAML_COMPLEX_ATTRIBUTE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_COMPLEX_ATTRIBUTE, GtkamlComplexAttributeClass))
+
+typedef struct _GtkamlComplexAttribute GtkamlComplexAttribute;
+typedef struct _GtkamlComplexAttributeClass GtkamlComplexAttributeClass;
+
+#define GTKAML_TYPE_METHOD (gtkaml_method_get_type ())
+#define GTKAML_METHOD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_METHOD, GtkamlMethod))
+#define GTKAML_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_METHOD, GtkamlMethodClass))
+#define GTKAML_IS_METHOD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_METHOD))
+#define GTKAML_IS_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_METHOD))
+#define GTKAML_METHOD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_METHOD, GtkamlMethodClass))
+
+typedef struct _GtkamlMethod GtkamlMethod;
+typedef struct _GtkamlMethodClass GtkamlMethodClass;
+
+#define GTKAML_TYPE_CONSTRUCT_METHOD (gtkaml_construct_method_get_type ())
+#define GTKAML_CONSTRUCT_METHOD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_CONSTRUCT_METHOD, GtkamlConstructMethod))
+#define GTKAML_CONSTRUCT_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_CONSTRUCT_METHOD, GtkamlConstructMethodClass))
+#define GTKAML_IS_CONSTRUCT_METHOD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_CONSTRUCT_METHOD))
+#define GTKAML_IS_CONSTRUCT_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_CONSTRUCT_METHOD))
+#define GTKAML_CONSTRUCT_METHOD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_CONSTRUCT_METHOD, GtkamlConstructMethodClass))
+
+typedef struct _GtkamlConstructMethod GtkamlConstructMethod;
+typedef struct _GtkamlConstructMethodClass GtkamlConstructMethodClass;
+
+#define GTKAML_TYPE_ADD_METHOD (gtkaml_add_method_get_type ())
+#define GTKAML_ADD_METHOD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_ADD_METHOD, GtkamlAddMethod))
+#define GTKAML_ADD_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_ADD_METHOD, GtkamlAddMethodClass))
+#define GTKAML_IS_ADD_METHOD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_ADD_METHOD))
+#define GTKAML_IS_ADD_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_ADD_METHOD))
+#define GTKAML_ADD_METHOD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_ADD_METHOD, GtkamlAddMethodClass))
+
+typedef struct _GtkamlAddMethod GtkamlAddMethod;
+typedef struct _GtkamlAddMethodClass GtkamlAddMethodClass;
+
+#define TYPE_DEFINITION_SCOPE (definition_scope_get_type ())
+
+#define GTKAML_TYPE_SIMPLE_ATTRIBUTE (gtkaml_simple_attribute_get_type ())
+#define GTKAML_SIMPLE_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_SIMPLE_ATTRIBUTE, GtkamlSimpleAttribute))
+#define GTKAML_SIMPLE_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_SIMPLE_ATTRIBUTE, GtkamlSimpleAttributeClass))
+#define GTKAML_IS_SIMPLE_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_SIMPLE_ATTRIBUTE))
+#define GTKAML_IS_SIMPLE_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_SIMPLE_ATTRIBUTE))
+#define GTKAML_SIMPLE_ATTRIBUTE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_SIMPLE_ATTRIBUTE, GtkamlSimpleAttributeClass))
+
+typedef struct _GtkamlSimpleAttribute GtkamlSimpleAttribute;
+typedef struct _GtkamlSimpleAttributeClass GtkamlSimpleAttributeClass;
+
+/**
+ * Generates vala source from a given ClassDefinition root tag
+ */
+struct _GtkamlCodeGenerator {
+	GObject parent_instance;
+	GtkamlCodeGeneratorPrivate * priv;
+};
+
+struct _GtkamlCodeGeneratorClass {
+	GObjectClass parent_class;
+};
 
-static char* string_substring (const char* self, glong offset, glong len);
 struct _GtkamlCodeGeneratorPrivate {
 	char* using_directives;
 	char* class_start;
@@ -59,15 +157,83 @@ struct _GtkamlCodeGeneratorPrivate {
 	GtkamlRootClassDefinition* _root_class_definition;
 };
 
+typedef enum  {
+	DEFINITION_SCOPE_MAIN_CLASS = 0,
+	DEFINITION_SCOPE_PUBLIC,
+	DEFINITION_SCOPE_PRIVATE,
+	DEFINITION_SCOPE_CONSTRUCTOR
+} DefinitionScope;
+
+
+
+GType gtkaml_code_generator_get_type (void);
+GType gtkaml_class_definition_get_type (void);
+GType gtkaml_root_class_definition_get_type (void);
 #define GTKAML_CODE_GENERATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GTKAML_TYPE_CODE_GENERATOR, GtkamlCodeGeneratorPrivate))
 enum  {
 	GTKAML_CODE_GENERATOR_DUMMY_PROPERTY,
 	GTKAML_CODE_GENERATOR_CONTEXT
 };
-static gint gtkaml_code_generator_line_count (GtkamlCodeGenerator* self, const char* s);
 static void gtkaml_code_generator_set_context (GtkamlCodeGenerator* self, ValaCodeContext* value);
+GtkamlCodeGenerator* gtkaml_code_generator_new (ValaCodeContext* context);
+GtkamlCodeGenerator* gtkaml_code_generator_construct (GType object_type, ValaCodeContext* context);
+GtkamlCodeGenerator* gtkaml_code_generator_new (ValaCodeContext* context);
+static gint gtkaml_code_generator_line_count (GtkamlCodeGenerator* self, const char* s);
 static GtkamlRootClassDefinition* gtkaml_code_generator_get_root_class_definition (GtkamlCodeGenerator* self);
+gint gtkaml_root_class_definition_get_original_first_code_line (GtkamlRootClassDefinition* self);
+char* gtkaml_code_generator_yield (GtkamlCodeGenerator* self);
 static void gtkaml_code_generator_set_root_class_definition (GtkamlCodeGenerator* self, GtkamlRootClassDefinition* value);
+GeeMap* gtkaml_root_class_definition_get_prefixes_namespaces (GtkamlRootClassDefinition* self);
+void gtkaml_code_generator_write_using (GtkamlCodeGenerator* self, const char* ns);
+char* gtkaml_code_generator_prefix_to_namespace (GtkamlCodeGenerator* self, const char* prefix);
+void gtkaml_code_generator_write_root_class_definition (GtkamlCodeGenerator* self, GtkamlRootClassDefinition* root_class_definition);
+void gtkaml_code_generator_write_preconstruct (GtkamlCodeGenerator* self, GtkamlClassDefinition* class_definition);
+void gtkaml_code_generator_write_root_constructor_parameters (GtkamlCodeGenerator* self, GtkamlRootClassDefinition* class_definition);
+void gtkaml_code_generator_write_complex_attributes (GtkamlCodeGenerator* self, GtkamlClassDefinition* class_definition);
+void gtkaml_code_generator_write_setters (GtkamlCodeGenerator* self, GtkamlClassDefinition* class_definition);
+void gtkaml_code_generator_generate_children (GtkamlCodeGenerator* self, GtkamlClassDefinition* class_definition);
+void gtkaml_code_generator_write_construct (GtkamlCodeGenerator* self, GtkamlClassDefinition* class_definition);
+GType gtkaml_reference_class_definition_get_type (void);
+void gtkaml_code_generator_write_add (GtkamlCodeGenerator* self, GtkamlClassDefinition* child_definition);
+void gtkaml_code_generator_write_declaration (GtkamlCodeGenerator* self, GtkamlClassDefinition* class_definition);
+void gtkaml_code_generator_write_constructor (GtkamlCodeGenerator* self, GtkamlClassDefinition* class_definition);
+void gtkaml_code_generator_generate (GtkamlCodeGenerator* self, GtkamlClassDefinition* class_definition);
+GeeList* gtkaml_class_definition_get_children (GtkamlClassDefinition* self);
+const char* gtkaml_class_definition_get_preconstruct_code (GtkamlClassDefinition* self);
+void gtkaml_code_generator_write_construct_call (GtkamlCodeGenerator* self, const char* identifier, const char* identifier_type, const char* construct_type, const char* construct_code);
+const char* gtkaml_class_definition_get_identifier (GtkamlClassDefinition* self);
+char* gtkaml_class_definition_get_base_full_name (GtkamlClassDefinition* self);
+const char* gtkaml_class_definition_get_construct_code (GtkamlClassDefinition* self);
+GType gtkaml_attribute_get_type (void);
+GeeList* gtkaml_class_definition_get_attrs (GtkamlClassDefinition* self);
+GType gtkaml_complex_attribute_get_type (void);
+GtkamlClassDefinition* gtkaml_complex_attribute_get_complex_type (GtkamlComplexAttribute* self);
+GType gtkaml_method_get_type (void);
+GType gtkaml_construct_method_get_type (void);
+GtkamlConstructMethod* gtkaml_class_definition_get_construct_method (GtkamlClassDefinition* self);
+GeeList* gtkaml_method_get_parameter_attributes (GtkamlMethod* self);
+GType gtkaml_add_method_get_type (void);
+GtkamlAddMethod* gtkaml_class_definition_get_add_method (GtkamlClassDefinition* self);
+const char* gtkaml_root_class_definition_get_target_namespace (GtkamlRootClassDefinition* self);
+const char* gtkaml_root_class_definition_get_target_name (GtkamlRootClassDefinition* self);
+const char* gtkaml_class_definition_get_base_ns (GtkamlClassDefinition* self);
+ValaClass* gtkaml_class_definition_get_base_type (GtkamlClassDefinition* self);
+const char* gtkaml_root_class_definition_get_implements (GtkamlRootClassDefinition* self);
+GeeList* gtkaml_root_class_definition_get_code (GtkamlRootClassDefinition* self);
+void gtkaml_code_generator_add_code (GtkamlCodeGenerator* self, const char* value);
+GType definition_scope_get_type (void);
+DefinitionScope gtkaml_class_definition_get_definition_scope (GtkamlClassDefinition* self);
+void gtkaml_code_generator_write_setter (GtkamlCodeGenerator* self, GtkamlClassDefinition* class_definition, GtkamlAttribute* attr);
+const char* gtkaml_method_get_name (GtkamlMethod* self);
+char* gtkaml_code_generator_generate_literal (GtkamlCodeGenerator* self, GtkamlAttribute* attr);
+GtkamlClassDefinition* gtkaml_class_definition_get_parent_container (GtkamlClassDefinition* self);
+ValaSymbol* gtkaml_attribute_get_target_type (GtkamlAttribute* self);
+void gtkaml_code_generator_write_signal_setter (GtkamlCodeGenerator* self, GtkamlClassDefinition* class_definition, GtkamlAttribute* signal_attr);
+ValaSourceReference* gtkaml_class_definition_get_source_reference (GtkamlClassDefinition* self);
+const char* gtkaml_attribute_get_name (GtkamlAttribute* self);
+GType gtkaml_simple_attribute_get_type (void);
+const char* gtkaml_simple_attribute_get_value (GtkamlSimpleAttribute* self);
+ValaCodeContext* gtkaml_code_generator_get_context (GtkamlCodeGenerator* self);
 static gpointer gtkaml_code_generator_parent_class = NULL;
 static void gtkaml_code_generator_finalize (GObject* obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
@@ -75,26 +241,6 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 
-static char* string_substring (const char* self, glong offset, glong len) {
-	glong string_length;
-	const char* start;
-	g_return_val_if_fail (self != NULL, NULL);
-	string_length = g_utf8_strlen (self, -1);
-	if (offset < 0) {
-		offset = string_length + offset;
-		g_return_val_if_fail (offset >= 0, NULL);
-	} else {
-		g_return_val_if_fail (offset <= string_length, NULL);
-	}
-	if (len < 0) {
-		len = string_length - offset;
-	}
-	g_return_val_if_fail ((offset + len) <= string_length, NULL);
-	start = g_utf8_offset_to_pointer (self, offset);
-	return g_strndup (start, ((gchar*) g_utf8_offset_to_pointer (start, len)) - ((gchar*) start));
-}
-
-
 GtkamlCodeGenerator* gtkaml_code_generator_construct (GType object_type, ValaCodeContext* context) {
 	GtkamlCodeGenerator * self;
 	g_return_val_if_fail (context != NULL, NULL);
@@ -290,6 +436,26 @@ void gtkaml_code_generator_write_construct (GtkamlCodeGenerator* self, GtkamlCla
 }
 
 
+static char* string_substring (const char* self, glong offset, glong len) {
+	glong string_length;
+	const char* start;
+	g_return_val_if_fail (self != NULL, NULL);
+	string_length = g_utf8_strlen (self, -1);
+	if (offset < 0) {
+		offset = string_length + offset;
+		g_return_val_if_fail (offset >= 0, NULL);
+	} else {
+		g_return_val_if_fail (offset <= string_length, NULL);
+	}
+	if (len < 0) {
+		len = string_length - offset;
+	}
+	g_return_val_if_fail ((offset + len) <= string_length, NULL);
+	start = g_utf8_offset_to_pointer (self, offset);
+	return g_strndup (start, ((gchar*) g_utf8_offset_to_pointer (start, len)) - ((gchar*) start));
+}
+
+
 void gtkaml_code_generator_write_construct_call (GtkamlCodeGenerator* self, const char* identifier, const char* identifier_type, const char* construct_type, const char* construct_code) {
 	char* _tmp0;
 	char* _tmp1;
@@ -1018,8 +1184,8 @@ void gtkaml_code_generator_write_signal_setter (GtkamlCodeGenerator* self, Gtkam
 	parameters_joined = (_tmp11 = g_strdup ("target"), parameters_joined = (g_free (parameters_joined), NULL), _tmp11);
 	if (gee_collection_get_size ((GeeCollection*) parameters) > 0) {
 		gint _tmp12;
-		gint _tmp17;
-		char* _tmp16;
+		char* _tmp17;
+		char* *_tmp16;
 		char* _tmp20;
 		char* _tmp19;
 		char* _tmp18;
@@ -1034,21 +1200,21 @@ void gtkaml_code_generator_write_signal_setter (GtkamlCodeGenerator* self, Gtkam
 			_p_it = gee_iterable_iterator ((GeeIterable*) parameters);
 			while (gee_iterator_next (_p_it)) {
 				ValaFormalParameter* p;
-				gint _tmp15;
-				char* _tmp14;
+				char* _tmp15;
+				char* *_tmp14;
 				const char* _tmp13;
 				p = (ValaFormalParameter*) gee_iterator_get (_p_it);
-				_tmp14 = NULL;
+				_tmp15 = NULL;
 				_tmp13 = NULL;
-				_tmp15 = i++;
-				parameter_names[_tmp15] = (_tmp14 = (_tmp13 = vala_symbol_get_name ((ValaSymbol*) p), (_tmp13 == NULL) ? NULL : g_strdup (_tmp13)), parameter_names[_tmp15] = (g_free (parameter_names[_tmp15]), NULL), _tmp14);
+				_tmp14 = &parameter_names[i++];
+				(*_tmp14) = (_tmp15 = (_tmp13 = vala_symbol_get_name ((ValaSymbol*) p), (_tmp13 == NULL) ? NULL : g_strdup (_tmp13)), (*_tmp14) = (g_free ((*_tmp14)), NULL), _tmp15);
 				(p == NULL) ? NULL : (p = (vala_code_node_unref (p), NULL));
 			}
 			(_p_it == NULL) ? NULL : (_p_it = (gee_collection_object_unref (_p_it), NULL));
 		}
-		_tmp16 = NULL;
-		_tmp17 = gee_collection_get_size ((GeeCollection*) parameters);
-		parameter_names[_tmp17] = (_tmp16 = NULL, parameter_names[_tmp17] = (g_free (parameter_names[_tmp17]), NULL), _tmp16);
+		_tmp17 = NULL;
+		_tmp16 = &parameter_names[gee_collection_get_size ((GeeCollection*) parameters)];
+		(*_tmp16) = (_tmp17 = NULL, (*_tmp16) = (g_free ((*_tmp16)), NULL), _tmp17);
 		_tmp20 = NULL;
 		_tmp19 = NULL;
 		_tmp18 = NULL;
