@@ -20,56 +20,209 @@
  *        Vlad Grecescu (b100dian@gmail.com)
  */
 
-#include "GtkamlImplicitsResolver.h"
-#include <gee/arraylist.h>
-#include <vala/valamethod.h>
-#include <vala/valaobjecttypesymbol.h>
-#include <gee/iterable.h>
-#include <gee/iterator.h>
-#include <vala/valacreationmethod.h>
-#include <gee/collection.h>
-#include <vala/valasymbol.h>
-#include <vala/valainterface.h>
-#include <gee/readonlylist.h>
-#include <vala/valadatatype.h>
-#include <vala/valaunresolvedtype.h>
-#include <vala/valaunresolvedsymbol.h>
-#include <vala/valanamespace.h>
-#include <vala/valascope.h>
-#include <vala/valareport.h>
-#include <vala/valasourcereference.h>
-#include <vala/valamember.h>
-#include "GtkamlReferenceClassDefinition.h"
-#include "GtkamlMethod.h"
-#include "GtkamlAttribute.h"
-#include "GtkamlSimpleAttribute.h"
-#include "GtkamlMethodMatcher.h"
-#include "GtkamlComplexAttribute.h"
+#include <glib.h>
+#include <glib-object.h>
+#include <vala.h>
+#include <gee.h>
+#include <stdlib.h>
+#include <string.h>
 
 
+#define GTKAML_TYPE_IMPLICITS_RESOLVER (gtkaml_implicits_resolver_get_type ())
+#define GTKAML_IMPLICITS_RESOLVER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_IMPLICITS_RESOLVER, GtkamlImplicitsResolver))
+#define GTKAML_IMPLICITS_RESOLVER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_IMPLICITS_RESOLVER, GtkamlImplicitsResolverClass))
+#define GTKAML_IS_IMPLICITS_RESOLVER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_IMPLICITS_RESOLVER))
+#define GTKAML_IS_IMPLICITS_RESOLVER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_IMPLICITS_RESOLVER))
+#define GTKAML_IMPLICITS_RESOLVER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_IMPLICITS_RESOLVER, GtkamlImplicitsResolverClass))
 
+typedef struct _GtkamlImplicitsResolver GtkamlImplicitsResolver;
+typedef struct _GtkamlImplicitsResolverClass GtkamlImplicitsResolverClass;
+typedef struct _GtkamlImplicitsResolverPrivate GtkamlImplicitsResolverPrivate;
+
+#define GTKAML_TYPE_IMPLICITS_STORE (gtkaml_implicits_store_get_type ())
+#define GTKAML_IMPLICITS_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_IMPLICITS_STORE, GtkamlImplicitsStore))
+#define GTKAML_IMPLICITS_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_IMPLICITS_STORE, GtkamlImplicitsStoreClass))
+#define GTKAML_IS_IMPLICITS_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_IMPLICITS_STORE))
+#define GTKAML_IS_IMPLICITS_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_IMPLICITS_STORE))
+#define GTKAML_IMPLICITS_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_IMPLICITS_STORE, GtkamlImplicitsStoreClass))
+
+typedef struct _GtkamlImplicitsStore GtkamlImplicitsStore;
+typedef struct _GtkamlImplicitsStoreClass GtkamlImplicitsStoreClass;
+
+#define GTKAML_TYPE_CLASS_DEFINITION (gtkaml_class_definition_get_type ())
+#define GTKAML_CLASS_DEFINITION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_CLASS_DEFINITION, GtkamlClassDefinition))
+#define GTKAML_CLASS_DEFINITION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_CLASS_DEFINITION, GtkamlClassDefinitionClass))
+#define GTKAML_IS_CLASS_DEFINITION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_CLASS_DEFINITION))
+#define GTKAML_IS_CLASS_DEFINITION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_CLASS_DEFINITION))
+#define GTKAML_CLASS_DEFINITION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_CLASS_DEFINITION, GtkamlClassDefinitionClass))
+
+typedef struct _GtkamlClassDefinition GtkamlClassDefinition;
+typedef struct _GtkamlClassDefinitionClass GtkamlClassDefinitionClass;
+
+#define GTKAML_TYPE_REFERENCE_CLASS_DEFINITION (gtkaml_reference_class_definition_get_type ())
+#define GTKAML_REFERENCE_CLASS_DEFINITION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_REFERENCE_CLASS_DEFINITION, GtkamlReferenceClassDefinition))
+#define GTKAML_REFERENCE_CLASS_DEFINITION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_REFERENCE_CLASS_DEFINITION, GtkamlReferenceClassDefinitionClass))
+#define GTKAML_IS_REFERENCE_CLASS_DEFINITION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_REFERENCE_CLASS_DEFINITION))
+#define GTKAML_IS_REFERENCE_CLASS_DEFINITION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_REFERENCE_CLASS_DEFINITION))
+#define GTKAML_REFERENCE_CLASS_DEFINITION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_REFERENCE_CLASS_DEFINITION, GtkamlReferenceClassDefinitionClass))
+
+typedef struct _GtkamlReferenceClassDefinition GtkamlReferenceClassDefinition;
+typedef struct _GtkamlReferenceClassDefinitionClass GtkamlReferenceClassDefinitionClass;
+
+#define GTKAML_TYPE_ATTRIBUTE (gtkaml_attribute_get_type ())
+#define GTKAML_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_ATTRIBUTE, GtkamlAttribute))
+#define GTKAML_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_ATTRIBUTE, GtkamlAttributeClass))
+#define GTKAML_IS_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_ATTRIBUTE))
+#define GTKAML_IS_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_ATTRIBUTE))
+#define GTKAML_ATTRIBUTE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_ATTRIBUTE, GtkamlAttributeClass))
+
+typedef struct _GtkamlAttribute GtkamlAttribute;
+typedef struct _GtkamlAttributeClass GtkamlAttributeClass;
+
+#define GTKAML_TYPE_COMPLEX_ATTRIBUTE (gtkaml_complex_attribute_get_type ())
+#define GTKAML_COMPLEX_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_COMPLEX_ATTRIBUTE, GtkamlComplexAttribute))
+#define GTKAML_COMPLEX_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_COMPLEX_ATTRIBUTE, GtkamlComplexAttributeClass))
+#define GTKAML_IS_COMPLEX_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_COMPLEX_ATTRIBUTE))
+#define GTKAML_IS_COMPLEX_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_COMPLEX_ATTRIBUTE))
+#define GTKAML_COMPLEX_ATTRIBUTE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_COMPLEX_ATTRIBUTE, GtkamlComplexAttributeClass))
+
+typedef struct _GtkamlComplexAttribute GtkamlComplexAttribute;
+typedef struct _GtkamlComplexAttributeClass GtkamlComplexAttributeClass;
+
+#define GTKAML_TYPE_METHOD (gtkaml_method_get_type ())
+#define GTKAML_METHOD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_METHOD, GtkamlMethod))
+#define GTKAML_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_METHOD, GtkamlMethodClass))
+#define GTKAML_IS_METHOD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_METHOD))
+#define GTKAML_IS_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_METHOD))
+#define GTKAML_METHOD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_METHOD, GtkamlMethodClass))
+
+typedef struct _GtkamlMethod GtkamlMethod;
+typedef struct _GtkamlMethodClass GtkamlMethodClass;
+
+#define GTKAML_TYPE_CONSTRUCT_METHOD (gtkaml_construct_method_get_type ())
+#define GTKAML_CONSTRUCT_METHOD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_CONSTRUCT_METHOD, GtkamlConstructMethod))
+#define GTKAML_CONSTRUCT_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_CONSTRUCT_METHOD, GtkamlConstructMethodClass))
+#define GTKAML_IS_CONSTRUCT_METHOD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_CONSTRUCT_METHOD))
+#define GTKAML_IS_CONSTRUCT_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_CONSTRUCT_METHOD))
+#define GTKAML_CONSTRUCT_METHOD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_CONSTRUCT_METHOD, GtkamlConstructMethodClass))
+
+typedef struct _GtkamlConstructMethod GtkamlConstructMethod;
+typedef struct _GtkamlConstructMethodClass GtkamlConstructMethodClass;
+
+#define GTKAML_TYPE_ADD_METHOD (gtkaml_add_method_get_type ())
+#define GTKAML_ADD_METHOD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_ADD_METHOD, GtkamlAddMethod))
+#define GTKAML_ADD_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_ADD_METHOD, GtkamlAddMethodClass))
+#define GTKAML_IS_ADD_METHOD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_ADD_METHOD))
+#define GTKAML_IS_ADD_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_ADD_METHOD))
+#define GTKAML_ADD_METHOD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_ADD_METHOD, GtkamlAddMethodClass))
+
+typedef struct _GtkamlAddMethod GtkamlAddMethod;
+typedef struct _GtkamlAddMethodClass GtkamlAddMethodClass;
+
+#define GTKAML_TYPE_SIMPLE_ATTRIBUTE (gtkaml_simple_attribute_get_type ())
+#define GTKAML_SIMPLE_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_SIMPLE_ATTRIBUTE, GtkamlSimpleAttribute))
+#define GTKAML_SIMPLE_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_SIMPLE_ATTRIBUTE, GtkamlSimpleAttributeClass))
+#define GTKAML_IS_SIMPLE_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_SIMPLE_ATTRIBUTE))
+#define GTKAML_IS_SIMPLE_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_SIMPLE_ATTRIBUTE))
+#define GTKAML_SIMPLE_ATTRIBUTE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_SIMPLE_ATTRIBUTE, GtkamlSimpleAttributeClass))
+
+typedef struct _GtkamlSimpleAttribute GtkamlSimpleAttribute;
+typedef struct _GtkamlSimpleAttributeClass GtkamlSimpleAttributeClass;
+
+#define GTKAML_TYPE_METHOD_MATCHER (gtkaml_method_matcher_get_type ())
+#define GTKAML_METHOD_MATCHER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_METHOD_MATCHER, GtkamlMethodMatcher))
+#define GTKAML_METHOD_MATCHER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_METHOD_MATCHER, GtkamlMethodMatcherClass))
+#define GTKAML_IS_METHOD_MATCHER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_METHOD_MATCHER))
+#define GTKAML_IS_METHOD_MATCHER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_METHOD_MATCHER))
+#define GTKAML_METHOD_MATCHER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_METHOD_MATCHER, GtkamlMethodMatcherClass))
+
+typedef struct _GtkamlMethodMatcher GtkamlMethodMatcher;
+typedef struct _GtkamlMethodMatcherClass GtkamlMethodMatcherClass;
+
+/** 
+ * determines which constructors to use or which container add functions to use;
+ * moves attributes from their ClassDefinition to the add or construct methods
+ */
+struct _GtkamlImplicitsResolver {
+	GObject parent_instance;
+	GtkamlImplicitsResolverPrivate * priv;
+};
+
+struct _GtkamlImplicitsResolverClass {
+	GObjectClass parent_class;
+};
 
 struct _GtkamlImplicitsResolverPrivate {
 	GtkamlImplicitsStore* _implicits_store;
 	ValaCodeContext* _context;
 };
 
+
+
+GType gtkaml_implicits_resolver_get_type (void);
+GType gtkaml_implicits_store_get_type (void);
 #define GTKAML_IMPLICITS_RESOLVER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GTKAML_TYPE_IMPLICITS_RESOLVER, GtkamlImplicitsResolverPrivate))
 enum  {
 	GTKAML_IMPLICITS_RESOLVER_DUMMY_PROPERTY,
 	GTKAML_IMPLICITS_RESOLVER_IMPLICITS_STORE,
 	GTKAML_IMPLICITS_RESOLVER_CONTEXT
 };
-static void gtkaml_implicits_resolver_determine_add_method (GtkamlImplicitsResolver* self, GtkamlClassDefinition* child_definition);
-static void gtkaml_implicits_resolver_determine_construct_method (GtkamlImplicitsResolver* self, GtkamlClassDefinition* class_definition);
-static void gtkaml_implicits_resolver_lookup_container_add_methods_for_class (GtkamlImplicitsResolver* self, const char* ns, ValaClass* container_class_implicits_entry, const char* ns2, ValaObjectTypeSymbol* container_class_holding_methods, GeeList* methods);
-static char* gtkaml_implicits_resolver_get_unresolved_type_ns (GtkamlImplicitsResolver* self, ValaUnresolvedType* dt);
-static void gtkaml_implicits_resolver_determine_attribute_types (GtkamlImplicitsResolver* self, GtkamlClassDefinition* class_definition);
-static ValaMember* gtkaml_implicits_resolver_member_lookup_inherited (GtkamlImplicitsResolver* self, ValaClass* clazz, const char* member);
-static ValaObjectTypeSymbol* gtkaml_implicits_resolver_lookup_class (GtkamlImplicitsResolver* self, const char* xmlNamespace, const char* name);
-static GeeList* gtkaml_implicits_resolver_lookup_constructors (GtkamlImplicitsResolver* self, ValaClass* clazz);
-static void gtkaml_implicits_resolver_set_implicits_store (GtkamlImplicitsResolver* self, GtkamlImplicitsStore* value);
 static void gtkaml_implicits_resolver_set_context (GtkamlImplicitsResolver* self, ValaCodeContext* value);
+static void gtkaml_implicits_resolver_set_implicits_store (GtkamlImplicitsResolver* self, GtkamlImplicitsStore* value);
+GtkamlImplicitsResolver* gtkaml_implicits_resolver_new (ValaCodeContext* context, GtkamlImplicitsStore* implicits_store);
+GtkamlImplicitsResolver* gtkaml_implicits_resolver_construct (GType object_type, ValaCodeContext* context, GtkamlImplicitsStore* implicits_store);
+GtkamlImplicitsResolver* gtkaml_implicits_resolver_new (ValaCodeContext* context, GtkamlImplicitsStore* implicits_store);
+GType gtkaml_class_definition_get_type (void);
+GType gtkaml_reference_class_definition_get_type (void);
+static void gtkaml_implicits_resolver_determine_construct_method (GtkamlImplicitsResolver* self, GtkamlClassDefinition* class_definition);
+GtkamlClassDefinition* gtkaml_class_definition_get_parent_container (GtkamlClassDefinition* self);
+static void gtkaml_implicits_resolver_determine_add_method (GtkamlImplicitsResolver* self, GtkamlClassDefinition* child_definition);
+GType gtkaml_attribute_get_type (void);
+GeeList* gtkaml_class_definition_get_attrs (GtkamlClassDefinition* self);
+ValaSourceReference* gtkaml_class_definition_get_source_reference (GtkamlClassDefinition* self);
+void gtkaml_implicits_resolver_resolve_complex_attributes (GtkamlImplicitsResolver* self, GtkamlClassDefinition* class_definition);
+static void gtkaml_implicits_resolver_determine_attribute_types (GtkamlImplicitsResolver* self, GtkamlClassDefinition* class_definition);
+GeeList* gtkaml_class_definition_get_children (GtkamlClassDefinition* self);
+void gtkaml_implicits_resolver_resolve (GtkamlImplicitsResolver* self, GtkamlClassDefinition* class_definition);
+GType gtkaml_complex_attribute_get_type (void);
+GtkamlClassDefinition* gtkaml_complex_attribute_get_complex_type (GtkamlComplexAttribute* self);
+GType gtkaml_method_get_type (void);
+GType gtkaml_construct_method_get_type (void);
+GtkamlConstructMethod* gtkaml_class_definition_get_construct_method (GtkamlClassDefinition* self);
+GeeList* gtkaml_method_get_parameter_attributes (GtkamlMethod* self);
+GType gtkaml_add_method_get_type (void);
+GtkamlAddMethod* gtkaml_class_definition_get_add_method (GtkamlClassDefinition* self);
+void gtkaml_implicits_resolver_lookup_container_add_methods (GtkamlImplicitsResolver* self, const char* ns, ValaClass* container_class, GeeList* methods);
+const char* gtkaml_class_definition_get_base_ns (GtkamlClassDefinition* self);
+ValaClass* gtkaml_class_definition_get_base_type (GtkamlClassDefinition* self);
+GtkamlAddMethod* gtkaml_add_method_new (void);
+GtkamlAddMethod* gtkaml_add_method_construct (GType object_type);
+GType gtkaml_simple_attribute_get_type (void);
+const char* gtkaml_attribute_get_name (GtkamlAttribute* self);
+const char* gtkaml_simple_attribute_get_value (GtkamlSimpleAttribute* self);
+GtkamlComplexAttribute* gtkaml_complex_attribute_new (const char* name, GtkamlClassDefinition* complex_type);
+GtkamlComplexAttribute* gtkaml_complex_attribute_construct (GType object_type, const char* name, GtkamlClassDefinition* complex_type);
+GtkamlImplicitsStore* gtkaml_implicits_resolver_get_implicits_store (GtkamlImplicitsResolver* self);
+GtkamlMethodMatcher* gtkaml_method_matcher_new (GtkamlImplicitsStore* implicits_store, GtkamlClassDefinition* class_owning_method, const char* wording, GtkamlComplexAttribute* first_parameter);
+GtkamlMethodMatcher* gtkaml_method_matcher_construct (GType object_type, GtkamlImplicitsStore* implicits_store, GtkamlClassDefinition* class_owning_method, const char* wording, GtkamlComplexAttribute* first_parameter);
+GType gtkaml_method_matcher_get_type (void);
+void gtkaml_method_matcher_add_method (GtkamlMethodMatcher* self, ValaMethod* method);
+ValaMethod* gtkaml_method_matcher_determine_matching_method (GtkamlMethodMatcher* self);
+void gtkaml_method_matcher_set_method_parameters (GtkamlMethodMatcher* self, GtkamlMethod* new_method, ValaMethod* determined_method);
+void gtkaml_class_definition_set_add_method (GtkamlClassDefinition* self, GtkamlAddMethod* value);
+static GeeList* gtkaml_implicits_resolver_lookup_constructors (GtkamlImplicitsResolver* self, ValaClass* clazz);
+GtkamlConstructMethod* gtkaml_construct_method_new (void);
+GtkamlConstructMethod* gtkaml_construct_method_construct (GType object_type);
+void gtkaml_class_definition_set_construct_method (GtkamlClassDefinition* self, GtkamlConstructMethod* value);
+static char* gtkaml_implicits_resolver_get_unresolved_type_ns (GtkamlImplicitsResolver* self, ValaUnresolvedType* dt);
+static ValaObjectTypeSymbol* gtkaml_implicits_resolver_lookup_class (GtkamlImplicitsResolver* self, const char* xmlNamespace, const char* name);
+static void gtkaml_implicits_resolver_lookup_container_add_methods_for_class (GtkamlImplicitsResolver* self, const char* ns, ValaClass* container_class_implicits_entry, const char* ns2, ValaObjectTypeSymbol* container_class_holding_methods, GeeList* methods);
+GeeList* gtkaml_implicits_store_get_adds (GtkamlImplicitsStore* self, const char* ns, const char* class_name);
+static ValaMember* gtkaml_implicits_resolver_member_lookup_inherited (GtkamlImplicitsResolver* self, ValaClass* clazz, const char* member);
+void gtkaml_attribute_set_target_type (GtkamlAttribute* self, ValaSymbol* value);
+ValaSymbol* gtkaml_attribute_get_target_type (GtkamlAttribute* self);
+char* gtkaml_class_definition_get_base_full_name (GtkamlClassDefinition* self);
+ValaCodeContext* gtkaml_implicits_resolver_get_context (GtkamlImplicitsResolver* self);
 static gpointer gtkaml_implicits_resolver_parent_class = NULL;
 static void gtkaml_implicits_resolver_finalize (GObject* obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
