@@ -20,44 +20,138 @@
  *        Vlad Grecescu (b100dian@gmail.com)
  */
 
-#include "GtkamlImplicitsStore.h"
-#include <gee/arraylist.h>
-#include <gee/hashmap.h>
-#include <gee/map.h>
-#include <gee/collection.h>
-#include <gee/iterable.h>
-#include <gee/iterator.h>
+#include <glib.h>
+#include <glib-object.h>
+#include <stdlib.h>
+#include <string.h>
+#include <gee.h>
 #include <glib/gstdio.h>
-#include <vala/valareport.h>
-#include <vala/valasourcereference.h>
-#include <vala/valasymbol.h>
-#include <vala/valacreationmethod.h>
-#include <vala/valaformalparameter.h>
+#include <vala.h>
 
 
+#define GTKAML_TYPE_IMPLICITS_PARAMETER (gtkaml_implicits_parameter_get_type ())
+#define GTKAML_IMPLICITS_PARAMETER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_IMPLICITS_PARAMETER, GtkamlImplicitsParameter))
+#define GTKAML_IMPLICITS_PARAMETER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_IMPLICITS_PARAMETER, GtkamlImplicitsParameterClass))
+#define GTKAML_IS_IMPLICITS_PARAMETER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_IMPLICITS_PARAMETER))
+#define GTKAML_IS_IMPLICITS_PARAMETER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_IMPLICITS_PARAMETER))
+#define GTKAML_IMPLICITS_PARAMETER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_IMPLICITS_PARAMETER, GtkamlImplicitsParameterClass))
 
+typedef struct _GtkamlImplicitsParameter GtkamlImplicitsParameter;
+typedef struct _GtkamlImplicitsParameterClass GtkamlImplicitsParameterClass;
+typedef struct _GtkamlImplicitsParameterPrivate GtkamlImplicitsParameterPrivate;
 
-enum  {
-	GTKAML_IMPLICITS_PARAMETER_DUMMY_PROPERTY
+#define GTKAML_TYPE_KEY_FILE_WRAPPER (gtkaml_key_file_wrapper_get_type ())
+#define GTKAML_KEY_FILE_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_KEY_FILE_WRAPPER, GtkamlKeyFileWrapper))
+#define GTKAML_KEY_FILE_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_KEY_FILE_WRAPPER, GtkamlKeyFileWrapperClass))
+#define GTKAML_IS_KEY_FILE_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_KEY_FILE_WRAPPER))
+#define GTKAML_IS_KEY_FILE_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_KEY_FILE_WRAPPER))
+#define GTKAML_KEY_FILE_WRAPPER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_KEY_FILE_WRAPPER, GtkamlKeyFileWrapperClass))
+
+typedef struct _GtkamlKeyFileWrapper GtkamlKeyFileWrapper;
+typedef struct _GtkamlKeyFileWrapperClass GtkamlKeyFileWrapperClass;
+typedef struct _GtkamlKeyFileWrapperPrivate GtkamlKeyFileWrapperPrivate;
+
+#define GTKAML_TYPE_IMPLICITS_STORE (gtkaml_implicits_store_get_type ())
+#define GTKAML_IMPLICITS_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_IMPLICITS_STORE, GtkamlImplicitsStore))
+#define GTKAML_IMPLICITS_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_IMPLICITS_STORE, GtkamlImplicitsStoreClass))
+#define GTKAML_IS_IMPLICITS_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_IMPLICITS_STORE))
+#define GTKAML_IS_IMPLICITS_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_IMPLICITS_STORE))
+#define GTKAML_IMPLICITS_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_IMPLICITS_STORE, GtkamlImplicitsStoreClass))
+
+typedef struct _GtkamlImplicitsStore GtkamlImplicitsStore;
+typedef struct _GtkamlImplicitsStoreClass GtkamlImplicitsStoreClass;
+typedef struct _GtkamlImplicitsStorePrivate GtkamlImplicitsStorePrivate;
+
+#define GTKAML_TYPE_CLASS_DEFINITION (gtkaml_class_definition_get_type ())
+#define GTKAML_CLASS_DEFINITION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_CLASS_DEFINITION, GtkamlClassDefinition))
+#define GTKAML_CLASS_DEFINITION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_CLASS_DEFINITION, GtkamlClassDefinitionClass))
+#define GTKAML_IS_CLASS_DEFINITION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_CLASS_DEFINITION))
+#define GTKAML_IS_CLASS_DEFINITION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_CLASS_DEFINITION))
+#define GTKAML_CLASS_DEFINITION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_CLASS_DEFINITION, GtkamlClassDefinitionClass))
+
+typedef struct _GtkamlClassDefinition GtkamlClassDefinition;
+typedef struct _GtkamlClassDefinitionClass GtkamlClassDefinitionClass;
+
+/** a method parameter as it came from an .implicits file, with its default value */
+struct _GtkamlImplicitsParameter {
+	GObject parent_instance;
+	GtkamlImplicitsParameterPrivate * priv;
+	char* name;
+	char* default_value;
 };
-static gpointer gtkaml_implicits_parameter_parent_class = NULL;
-static void gtkaml_implicits_parameter_finalize (GObject* obj);
-enum  {
-	GTKAML_KEY_FILE_WRAPPER_DUMMY_PROPERTY
+
+struct _GtkamlImplicitsParameterClass {
+	GObjectClass parent_class;
 };
-static GObject * gtkaml_key_file_wrapper_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
-static gpointer gtkaml_key_file_wrapper_parent_class = NULL;
-static void gtkaml_key_file_wrapper_finalize (GObject* obj);
+
+/**
+ * GObject-ification of KeyFile
+ */
+struct _GtkamlKeyFileWrapper {
+	GObject parent_instance;
+	GtkamlKeyFileWrapperPrivate * priv;
+	GKeyFile* key_file;
+};
+
+struct _GtkamlKeyFileWrapperClass {
+	GObjectClass parent_class;
+};
+
+/** 
+ * collects $(ns).implicits key files and provides key information from all of them
+ */
+struct _GtkamlImplicitsStore {
+	GObject parent_instance;
+	GtkamlImplicitsStorePrivate * priv;
+};
+
+struct _GtkamlImplicitsStoreClass {
+	GObjectClass parent_class;
+};
+
 struct _GtkamlImplicitsStorePrivate {
 	GeeList* implicits_dirs;
 	GeeMap* loaded_ns;
 };
 
+
+
+GType gtkaml_implicits_parameter_get_type (void);
+enum  {
+	GTKAML_IMPLICITS_PARAMETER_DUMMY_PROPERTY
+};
+GtkamlImplicitsParameter* gtkaml_implicits_parameter_new (void);
+GtkamlImplicitsParameter* gtkaml_implicits_parameter_construct (GType object_type);
+GtkamlImplicitsParameter* gtkaml_implicits_parameter_new (void);
+static gpointer gtkaml_implicits_parameter_parent_class = NULL;
+static void gtkaml_implicits_parameter_finalize (GObject* obj);
+GType gtkaml_key_file_wrapper_get_type (void);
+enum  {
+	GTKAML_KEY_FILE_WRAPPER_DUMMY_PROPERTY
+};
+gboolean gtkaml_key_file_wrapper_has_key (GtkamlKeyFileWrapper* self, const char* group, const char* key);
+char** gtkaml_key_file_wrapper_get_string_list (GtkamlKeyFileWrapper* self, const char* group, const char* key, int* result_length1);
+GtkamlKeyFileWrapper* gtkaml_key_file_wrapper_new (void);
+GtkamlKeyFileWrapper* gtkaml_key_file_wrapper_construct (GType object_type);
+GtkamlKeyFileWrapper* gtkaml_key_file_wrapper_new (void);
+static GObject * gtkaml_key_file_wrapper_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
+static gpointer gtkaml_key_file_wrapper_parent_class = NULL;
+static void gtkaml_key_file_wrapper_finalize (GObject* obj);
+GType gtkaml_implicits_store_get_type (void);
 #define GTKAML_IMPLICITS_STORE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GTKAML_TYPE_IMPLICITS_STORE, GtkamlImplicitsStorePrivate))
 enum  {
 	GTKAML_IMPLICITS_STORE_DUMMY_PROPERTY
 };
+GeeReadOnlyList* gtkaml_implicits_store_get_implicits_dirs (GtkamlImplicitsStore* self);
+void gtkaml_implicits_store_add_implicits_dir (GtkamlImplicitsStore* self, const char* directory);
 static GeeList* gtkaml_implicits_store_get_ns (GtkamlImplicitsStore* self, const char* ns);
+GeeList* gtkaml_implicits_store_get_adds (GtkamlImplicitsStore* self, const char* ns, const char* class_name);
+GeeList* gtkaml_implicits_store_get_method_parameters (GtkamlImplicitsStore* self, const char* ns, const char* class_name, const char* method_name);
+GType gtkaml_class_definition_get_type (void);
+GeeList* gtkaml_implicits_store_determine_parameter_names_and_default_values (GtkamlImplicitsStore* self, GtkamlClassDefinition* class_definition, ValaMethod* method);
+GtkamlImplicitsStore* gtkaml_implicits_store_new (void);
+GtkamlImplicitsStore* gtkaml_implicits_store_construct (GType object_type);
+GtkamlImplicitsStore* gtkaml_implicits_store_new (void);
 static gpointer gtkaml_implicits_store_parent_class = NULL;
 static void gtkaml_implicits_store_finalize (GObject* obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
