@@ -20,34 +20,125 @@
  *        Vlad Grecescu (b100dian@gmail.com)
  */
 
-#include "GtkamlMethod.h"
-#include <gee/arraylist.h>
-#include "GtkamlAttribute.h"
+#include <glib.h>
+#include <glib-object.h>
+#include <stdlib.h>
+#include <string.h>
+#include <gee.h>
 
 
+#define GTKAML_TYPE_METHOD (gtkaml_method_get_type ())
+#define GTKAML_METHOD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_METHOD, GtkamlMethod))
+#define GTKAML_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_METHOD, GtkamlMethodClass))
+#define GTKAML_IS_METHOD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_METHOD))
+#define GTKAML_IS_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_METHOD))
+#define GTKAML_METHOD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_METHOD, GtkamlMethodClass))
 
+typedef struct _GtkamlMethod GtkamlMethod;
+typedef struct _GtkamlMethodClass GtkamlMethodClass;
+typedef struct _GtkamlMethodPrivate GtkamlMethodPrivate;
+
+#define GTKAML_TYPE_ATTRIBUTE (gtkaml_attribute_get_type ())
+#define GTKAML_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_ATTRIBUTE, GtkamlAttribute))
+#define GTKAML_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_ATTRIBUTE, GtkamlAttributeClass))
+#define GTKAML_IS_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_ATTRIBUTE))
+#define GTKAML_IS_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_ATTRIBUTE))
+#define GTKAML_ATTRIBUTE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_ATTRIBUTE, GtkamlAttributeClass))
+
+typedef struct _GtkamlAttribute GtkamlAttribute;
+typedef struct _GtkamlAttributeClass GtkamlAttributeClass;
+
+#define GTKAML_TYPE_ADD_METHOD (gtkaml_add_method_get_type ())
+#define GTKAML_ADD_METHOD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_ADD_METHOD, GtkamlAddMethod))
+#define GTKAML_ADD_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_ADD_METHOD, GtkamlAddMethodClass))
+#define GTKAML_IS_ADD_METHOD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_ADD_METHOD))
+#define GTKAML_IS_ADD_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_ADD_METHOD))
+#define GTKAML_ADD_METHOD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_ADD_METHOD, GtkamlAddMethodClass))
+
+typedef struct _GtkamlAddMethod GtkamlAddMethod;
+typedef struct _GtkamlAddMethodClass GtkamlAddMethodClass;
+typedef struct _GtkamlAddMethodPrivate GtkamlAddMethodPrivate;
+
+#define GTKAML_TYPE_CONSTRUCT_METHOD (gtkaml_construct_method_get_type ())
+#define GTKAML_CONSTRUCT_METHOD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_CONSTRUCT_METHOD, GtkamlConstructMethod))
+#define GTKAML_CONSTRUCT_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_CONSTRUCT_METHOD, GtkamlConstructMethodClass))
+#define GTKAML_IS_CONSTRUCT_METHOD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_CONSTRUCT_METHOD))
+#define GTKAML_IS_CONSTRUCT_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_CONSTRUCT_METHOD))
+#define GTKAML_CONSTRUCT_METHOD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_CONSTRUCT_METHOD, GtkamlConstructMethodClass))
+
+typedef struct _GtkamlConstructMethod GtkamlConstructMethod;
+typedef struct _GtkamlConstructMethodClass GtkamlConstructMethodClass;
+typedef struct _GtkamlConstructMethodPrivate GtkamlConstructMethodPrivate;
+
+/**
+ * a constructor or an add method
+ */
+struct _GtkamlMethod {
+	GObject parent_instance;
+	GtkamlMethodPrivate * priv;
+};
+
+struct _GtkamlMethodClass {
+	GObjectClass parent_class;
+};
 
 struct _GtkamlMethodPrivate {
 	char* _name;
 	GeeList* _parameter_attributes;
 };
 
+/** useless specialization */
+struct _GtkamlAddMethod {
+	GtkamlMethod parent_instance;
+	GtkamlAddMethodPrivate * priv;
+};
+
+struct _GtkamlAddMethodClass {
+	GtkamlMethodClass parent_class;
+};
+
+/** useless specialization */
+struct _GtkamlConstructMethod {
+	GtkamlMethod parent_instance;
+	GtkamlConstructMethodPrivate * priv;
+};
+
+struct _GtkamlConstructMethodClass {
+	GtkamlMethodClass parent_class;
+};
+
+
+
+GType gtkaml_method_get_type (void);
+GType gtkaml_attribute_get_type (void);
 #define GTKAML_METHOD_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GTKAML_TYPE_METHOD, GtkamlMethodPrivate))
 enum  {
 	GTKAML_METHOD_DUMMY_PROPERTY,
 	GTKAML_METHOD_NAME,
 	GTKAML_METHOD_PARAMETER_ATTRIBUTES
 };
+const char* gtkaml_method_get_name (GtkamlMethod* self);
+void gtkaml_method_set_name (GtkamlMethod* self, const char* value);
+GeeList* gtkaml_method_get_parameter_attributes (GtkamlMethod* self);
+void gtkaml_method_set_parameter_attributes (GtkamlMethod* self, GeeList* value);
 static GObject * gtkaml_method_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer gtkaml_method_parent_class = NULL;
 static void gtkaml_method_finalize (GObject* obj);
+GType gtkaml_add_method_get_type (void);
 enum  {
 	GTKAML_ADD_METHOD_DUMMY_PROPERTY
 };
+GtkamlAddMethod* gtkaml_add_method_new (void);
+GtkamlAddMethod* gtkaml_add_method_construct (GType object_type);
+GtkamlAddMethod* gtkaml_add_method_new (void);
 static gpointer gtkaml_add_method_parent_class = NULL;
+GType gtkaml_construct_method_get_type (void);
 enum  {
 	GTKAML_CONSTRUCT_METHOD_DUMMY_PROPERTY
 };
+GtkamlConstructMethod* gtkaml_construct_method_new (void);
+GtkamlConstructMethod* gtkaml_construct_method_construct (GType object_type);
+GtkamlConstructMethod* gtkaml_construct_method_new (void);
 static gpointer gtkaml_construct_method_parent_class = NULL;
 
 
