@@ -20,21 +20,104 @@
  *        Vlad Grecescu (b100dian@gmail.com)
  */
 
-#include "GtkamlMethodMatcher.h"
-#include <gee/arraylist.h>
-#include <gee/list.h>
-#include <gee/collection.h>
-#include <gee/iterable.h>
-#include <gee/iterator.h>
-#include <vala/valareport.h>
-#include <vala/valasourcereference.h>
-#include <vala/valasymbol.h>
-#include <vala/valaformalparameter.h>
-#include "GtkamlAttribute.h"
-#include "GtkamlSimpleAttribute.h"
+#include <glib.h>
+#include <glib-object.h>
+#include <stdlib.h>
+#include <string.h>
+#include <gee.h>
+#include <vala.h>
 
 
+#define GTKAML_TYPE_METHOD_MATCHER (gtkaml_method_matcher_get_type ())
+#define GTKAML_METHOD_MATCHER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_METHOD_MATCHER, GtkamlMethodMatcher))
+#define GTKAML_METHOD_MATCHER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_METHOD_MATCHER, GtkamlMethodMatcherClass))
+#define GTKAML_IS_METHOD_MATCHER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_METHOD_MATCHER))
+#define GTKAML_IS_METHOD_MATCHER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_METHOD_MATCHER))
+#define GTKAML_METHOD_MATCHER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_METHOD_MATCHER, GtkamlMethodMatcherClass))
 
+typedef struct _GtkamlMethodMatcher GtkamlMethodMatcher;
+typedef struct _GtkamlMethodMatcherClass GtkamlMethodMatcherClass;
+typedef struct _GtkamlMethodMatcherPrivate GtkamlMethodMatcherPrivate;
+
+#define GTKAML_TYPE_CLASS_DEFINITION (gtkaml_class_definition_get_type ())
+#define GTKAML_CLASS_DEFINITION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_CLASS_DEFINITION, GtkamlClassDefinition))
+#define GTKAML_CLASS_DEFINITION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_CLASS_DEFINITION, GtkamlClassDefinitionClass))
+#define GTKAML_IS_CLASS_DEFINITION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_CLASS_DEFINITION))
+#define GTKAML_IS_CLASS_DEFINITION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_CLASS_DEFINITION))
+#define GTKAML_CLASS_DEFINITION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_CLASS_DEFINITION, GtkamlClassDefinitionClass))
+
+typedef struct _GtkamlClassDefinition GtkamlClassDefinition;
+typedef struct _GtkamlClassDefinitionClass GtkamlClassDefinitionClass;
+
+#define GTKAML_TYPE_ATTRIBUTE (gtkaml_attribute_get_type ())
+#define GTKAML_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_ATTRIBUTE, GtkamlAttribute))
+#define GTKAML_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_ATTRIBUTE, GtkamlAttributeClass))
+#define GTKAML_IS_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_ATTRIBUTE))
+#define GTKAML_IS_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_ATTRIBUTE))
+#define GTKAML_ATTRIBUTE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_ATTRIBUTE, GtkamlAttributeClass))
+
+typedef struct _GtkamlAttribute GtkamlAttribute;
+typedef struct _GtkamlAttributeClass GtkamlAttributeClass;
+
+#define GTKAML_TYPE_COMPLEX_ATTRIBUTE (gtkaml_complex_attribute_get_type ())
+#define GTKAML_COMPLEX_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_COMPLEX_ATTRIBUTE, GtkamlComplexAttribute))
+#define GTKAML_COMPLEX_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_COMPLEX_ATTRIBUTE, GtkamlComplexAttributeClass))
+#define GTKAML_IS_COMPLEX_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_COMPLEX_ATTRIBUTE))
+#define GTKAML_IS_COMPLEX_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_COMPLEX_ATTRIBUTE))
+#define GTKAML_COMPLEX_ATTRIBUTE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_COMPLEX_ATTRIBUTE, GtkamlComplexAttributeClass))
+
+typedef struct _GtkamlComplexAttribute GtkamlComplexAttribute;
+typedef struct _GtkamlComplexAttributeClass GtkamlComplexAttributeClass;
+
+#define GTKAML_TYPE_IMPLICITS_STORE (gtkaml_implicits_store_get_type ())
+#define GTKAML_IMPLICITS_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_IMPLICITS_STORE, GtkamlImplicitsStore))
+#define GTKAML_IMPLICITS_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_IMPLICITS_STORE, GtkamlImplicitsStoreClass))
+#define GTKAML_IS_IMPLICITS_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_IMPLICITS_STORE))
+#define GTKAML_IS_IMPLICITS_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_IMPLICITS_STORE))
+#define GTKAML_IMPLICITS_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_IMPLICITS_STORE, GtkamlImplicitsStoreClass))
+
+typedef struct _GtkamlImplicitsStore GtkamlImplicitsStore;
+typedef struct _GtkamlImplicitsStoreClass GtkamlImplicitsStoreClass;
+
+#define GTKAML_TYPE_IMPLICITS_PARAMETER (gtkaml_implicits_parameter_get_type ())
+#define GTKAML_IMPLICITS_PARAMETER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_IMPLICITS_PARAMETER, GtkamlImplicitsParameter))
+#define GTKAML_IMPLICITS_PARAMETER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_IMPLICITS_PARAMETER, GtkamlImplicitsParameterClass))
+#define GTKAML_IS_IMPLICITS_PARAMETER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_IMPLICITS_PARAMETER))
+#define GTKAML_IS_IMPLICITS_PARAMETER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_IMPLICITS_PARAMETER))
+#define GTKAML_IMPLICITS_PARAMETER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_IMPLICITS_PARAMETER, GtkamlImplicitsParameterClass))
+
+typedef struct _GtkamlImplicitsParameter GtkamlImplicitsParameter;
+typedef struct _GtkamlImplicitsParameterClass GtkamlImplicitsParameterClass;
+typedef struct _GtkamlImplicitsParameterPrivate GtkamlImplicitsParameterPrivate;
+
+#define GTKAML_TYPE_SIMPLE_ATTRIBUTE (gtkaml_simple_attribute_get_type ())
+#define GTKAML_SIMPLE_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_SIMPLE_ATTRIBUTE, GtkamlSimpleAttribute))
+#define GTKAML_SIMPLE_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_SIMPLE_ATTRIBUTE, GtkamlSimpleAttributeClass))
+#define GTKAML_IS_SIMPLE_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_SIMPLE_ATTRIBUTE))
+#define GTKAML_IS_SIMPLE_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_SIMPLE_ATTRIBUTE))
+#define GTKAML_SIMPLE_ATTRIBUTE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_SIMPLE_ATTRIBUTE, GtkamlSimpleAttributeClass))
+
+typedef struct _GtkamlSimpleAttribute GtkamlSimpleAttribute;
+typedef struct _GtkamlSimpleAttributeClass GtkamlSimpleAttributeClass;
+
+#define GTKAML_TYPE_METHOD (gtkaml_method_get_type ())
+#define GTKAML_METHOD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_METHOD, GtkamlMethod))
+#define GTKAML_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_METHOD, GtkamlMethodClass))
+#define GTKAML_IS_METHOD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_METHOD))
+#define GTKAML_IS_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_METHOD))
+#define GTKAML_METHOD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_METHOD, GtkamlMethodClass))
+
+typedef struct _GtkamlMethod GtkamlMethod;
+typedef struct _GtkamlMethodClass GtkamlMethodClass;
+
+struct _GtkamlMethodMatcher {
+	GObject parent_instance;
+	GtkamlMethodMatcherPrivate * priv;
+};
+
+struct _GtkamlMethodMatcherClass {
+	GObjectClass parent_class;
+};
 
 struct _GtkamlMethodMatcherPrivate {
 	GtkamlClassDefinition* _class_owning_method;
@@ -52,6 +135,26 @@ struct _GtkamlMethodMatcherPrivate {
 	gint count_with_max_match;
 };
 
+/** a method parameter as it came from an .implicits file, with its default value */
+struct _GtkamlImplicitsParameter {
+	GObject parent_instance;
+	GtkamlImplicitsParameterPrivate * priv;
+	char* name;
+	char* default_value;
+};
+
+struct _GtkamlImplicitsParameterClass {
+	GObjectClass parent_class;
+};
+
+
+
+GType gtkaml_method_matcher_get_type (void);
+GType gtkaml_class_definition_get_type (void);
+GType gtkaml_attribute_get_type (void);
+GType gtkaml_complex_attribute_get_type (void);
+GType gtkaml_implicits_store_get_type (void);
+GType gtkaml_implicits_parameter_get_type (void);
 #define GTKAML_METHOD_MATCHER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GTKAML_TYPE_METHOD_MATCHER, GtkamlMethodMatcherPrivate))
 enum  {
 	GTKAML_METHOD_MATCHER_DUMMY_PROPERTY,
@@ -60,10 +163,34 @@ enum  {
 	GTKAML_METHOD_MATCHER_FIRST_PARAMETER,
 	GTKAML_METHOD_MATCHER_IMPLICITS_STORE
 };
+static void gtkaml_method_matcher_set_implicits_store (GtkamlMethodMatcher* self, GtkamlImplicitsStore* value);
 static void gtkaml_method_matcher_set_class_owning_method (GtkamlMethodMatcher* self, GtkamlClassDefinition* value);
 static void gtkaml_method_matcher_set_wording (GtkamlMethodMatcher* self, const char* value);
 static void gtkaml_method_matcher_set_first_parameter (GtkamlMethodMatcher* self, GtkamlComplexAttribute* value);
-static void gtkaml_method_matcher_set_implicits_store (GtkamlMethodMatcher* self, GtkamlImplicitsStore* value);
+GtkamlMethodMatcher* gtkaml_method_matcher_new (GtkamlImplicitsStore* implicits_store, GtkamlClassDefinition* class_owning_method, const char* wording, GtkamlComplexAttribute* first_parameter);
+GtkamlMethodMatcher* gtkaml_method_matcher_construct (GType object_type, GtkamlImplicitsStore* implicits_store, GtkamlClassDefinition* class_owning_method, const char* wording, GtkamlComplexAttribute* first_parameter);
+GtkamlMethodMatcher* gtkaml_method_matcher_new (GtkamlImplicitsStore* implicits_store, GtkamlClassDefinition* class_owning_method, const char* wording, GtkamlComplexAttribute* first_parameter);
+void gtkaml_method_matcher_add_method (GtkamlMethodMatcher* self, ValaMethod* method);
+GtkamlImplicitsStore* gtkaml_method_matcher_get_implicits_store (GtkamlMethodMatcher* self);
+GeeList* gtkaml_implicits_store_determine_parameter_names_and_default_values (GtkamlImplicitsStore* self, GtkamlClassDefinition* class_definition, ValaMethod* method);
+GtkamlClassDefinition* gtkaml_method_matcher_get_class_owning_method (GtkamlMethodMatcher* self);
+GeeList* gtkaml_class_definition_get_attrs (GtkamlClassDefinition* self);
+const char* gtkaml_attribute_get_name (GtkamlAttribute* self);
+GtkamlComplexAttribute* gtkaml_method_matcher_get_first_parameter (GtkamlMethodMatcher* self);
+ValaSourceReference* gtkaml_class_definition_get_source_reference (GtkamlClassDefinition* self);
+char* gtkaml_class_definition_get_base_full_name (GtkamlClassDefinition* self);
+const char* gtkaml_method_matcher_get_wording (GtkamlMethodMatcher* self);
+GtkamlClassDefinition* gtkaml_complex_attribute_get_complex_type (GtkamlComplexAttribute* self);
+void gtkaml_class_definition_add_attribute (GtkamlClassDefinition* self, GtkamlAttribute* attr);
+GtkamlSimpleAttribute* gtkaml_simple_attribute_new (const char* name, const char* value);
+GtkamlSimpleAttribute* gtkaml_simple_attribute_construct (GType object_type, const char* name, const char* value);
+GType gtkaml_simple_attribute_get_type (void);
+ValaMethod* gtkaml_method_matcher_determine_matching_method (GtkamlMethodMatcher* self);
+GType gtkaml_method_get_type (void);
+void gtkaml_method_set_name (GtkamlMethod* self, const char* value);
+GeeList* gtkaml_method_get_parameter_attributes (GtkamlMethod* self);
+void gtkaml_attribute_set_target_type (GtkamlAttribute* self, ValaSymbol* value);
+void gtkaml_method_matcher_set_method_parameters (GtkamlMethodMatcher* self, GtkamlMethod* new_method, ValaMethod* determined_method);
 static GObject * gtkaml_method_matcher_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer gtkaml_method_matcher_parent_class = NULL;
 static void gtkaml_method_matcher_finalize (GObject* obj);
