@@ -61,7 +61,7 @@ struct _GtkamlParserClass {
 
 GtkamlParser* gtkaml_parser_construct (GType object_type);
 GtkamlParser* gtkaml_parser_new (void);
-void gtkaml_parser_parse (GtkamlParser* self, ValaCodeContext* context, char** implicits_directories);
+void gtkaml_parser_parse (GtkamlParser* self, ValaCodeContext* context, char** implicits_directories, int implicits_directories_length1);
 void gtkaml_parser_parse_gtkaml_file (GtkamlParser* self, ValaSourceFile* gtkaml_source_file);
 GType gtkaml_parser_get_type (void);
 
