@@ -20,12 +20,87 @@
  *        Vlad Grecescu (b100dian@gmail.com)
  */
 
-#include "GtkamlRootClassDefinition.h"
-#include <gee/arraylist.h>
-#include "GtkamlAttribute.h"
+#include <glib.h>
+#include <glib-object.h>
+#include <gee.h>
+#include <stdlib.h>
+#include <string.h>
+#include <vala.h>
 
 
+#define GTKAML_TYPE_CLASS_DEFINITION (gtkaml_class_definition_get_type ())
+#define GTKAML_CLASS_DEFINITION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_CLASS_DEFINITION, GtkamlClassDefinition))
+#define GTKAML_CLASS_DEFINITION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_CLASS_DEFINITION, GtkamlClassDefinitionClass))
+#define GTKAML_IS_CLASS_DEFINITION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_CLASS_DEFINITION))
+#define GTKAML_IS_CLASS_DEFINITION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_CLASS_DEFINITION))
+#define GTKAML_CLASS_DEFINITION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_CLASS_DEFINITION, GtkamlClassDefinitionClass))
 
+typedef struct _GtkamlClassDefinition GtkamlClassDefinition;
+typedef struct _GtkamlClassDefinitionClass GtkamlClassDefinitionClass;
+typedef struct _GtkamlClassDefinitionPrivate GtkamlClassDefinitionPrivate;
+
+#define GTKAML_TYPE_ROOT_CLASS_DEFINITION (gtkaml_root_class_definition_get_type ())
+#define GTKAML_ROOT_CLASS_DEFINITION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_ROOT_CLASS_DEFINITION, GtkamlRootClassDefinition))
+#define GTKAML_ROOT_CLASS_DEFINITION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_ROOT_CLASS_DEFINITION, GtkamlRootClassDefinitionClass))
+#define GTKAML_IS_ROOT_CLASS_DEFINITION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_ROOT_CLASS_DEFINITION))
+#define GTKAML_IS_ROOT_CLASS_DEFINITION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_ROOT_CLASS_DEFINITION))
+#define GTKAML_ROOT_CLASS_DEFINITION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_ROOT_CLASS_DEFINITION, GtkamlRootClassDefinitionClass))
+
+typedef struct _GtkamlRootClassDefinition GtkamlRootClassDefinition;
+typedef struct _GtkamlRootClassDefinitionClass GtkamlRootClassDefinitionClass;
+typedef struct _GtkamlRootClassDefinitionPrivate GtkamlRootClassDefinitionPrivate;
+
+#define TYPE_DEFINITION_SCOPE (definition_scope_get_type ())
+
+#define GTKAML_TYPE_ATTRIBUTE (gtkaml_attribute_get_type ())
+#define GTKAML_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_ATTRIBUTE, GtkamlAttribute))
+#define GTKAML_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_ATTRIBUTE, GtkamlAttributeClass))
+#define GTKAML_IS_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_ATTRIBUTE))
+#define GTKAML_IS_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_ATTRIBUTE))
+#define GTKAML_ATTRIBUTE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_ATTRIBUTE, GtkamlAttributeClass))
+
+typedef struct _GtkamlAttribute GtkamlAttribute;
+typedef struct _GtkamlAttributeClass GtkamlAttributeClass;
+
+#define GTKAML_TYPE_METHOD (gtkaml_method_get_type ())
+#define GTKAML_METHOD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_METHOD, GtkamlMethod))
+#define GTKAML_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_METHOD, GtkamlMethodClass))
+#define GTKAML_IS_METHOD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_METHOD))
+#define GTKAML_IS_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_METHOD))
+#define GTKAML_METHOD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_METHOD, GtkamlMethodClass))
+
+typedef struct _GtkamlMethod GtkamlMethod;
+typedef struct _GtkamlMethodClass GtkamlMethodClass;
+
+#define GTKAML_TYPE_CONSTRUCT_METHOD (gtkaml_construct_method_get_type ())
+#define GTKAML_CONSTRUCT_METHOD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_CONSTRUCT_METHOD, GtkamlConstructMethod))
+#define GTKAML_CONSTRUCT_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_CONSTRUCT_METHOD, GtkamlConstructMethodClass))
+#define GTKAML_IS_CONSTRUCT_METHOD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_CONSTRUCT_METHOD))
+#define GTKAML_IS_CONSTRUCT_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_CONSTRUCT_METHOD))
+#define GTKAML_CONSTRUCT_METHOD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_CONSTRUCT_METHOD, GtkamlConstructMethodClass))
+
+typedef struct _GtkamlConstructMethod GtkamlConstructMethod;
+typedef struct _GtkamlConstructMethodClass GtkamlConstructMethodClass;
+
+/** represents a gtkaml tag */
+struct _GtkamlClassDefinition {
+	GObject parent_instance;
+	GtkamlClassDefinitionPrivate * priv;
+};
+
+struct _GtkamlClassDefinitionClass {
+	GObjectClass parent_class;
+};
+
+/** represents the definition of the root tag */
+struct _GtkamlRootClassDefinition {
+	GtkamlClassDefinition parent_instance;
+	GtkamlRootClassDefinitionPrivate * priv;
+};
+
+struct _GtkamlRootClassDefinitionClass {
+	GtkamlClassDefinitionClass parent_class;
+};
 
 struct _GtkamlRootClassDefinitionPrivate {
 	GeeMap* _prefixes_namespaces;
@@ -36,6 +111,17 @@ struct _GtkamlRootClassDefinitionPrivate {
 	char* _implements;
 };
 
+typedef enum  {
+	DEFINITION_SCOPE_MAIN_CLASS = 0,
+	DEFINITION_SCOPE_PUBLIC,
+	DEFINITION_SCOPE_PRIVATE,
+	DEFINITION_SCOPE_CONSTRUCTOR
+} DefinitionScope;
+
+
+
+GType gtkaml_class_definition_get_type (void);
+GType gtkaml_root_class_definition_get_type (void);
 #define GTKAML_ROOT_CLASS_DEFINITION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GTKAML_TYPE_ROOT_CLASS_DEFINITION, GtkamlRootClassDefinitionPrivate))
 enum  {
 	GTKAML_ROOT_CLASS_DEFINITION_DUMMY_PROPERTY,
@@ -46,6 +132,36 @@ enum  {
 	GTKAML_ROOT_CLASS_DEFINITION_ORIGINAL_FIRST_CODE_LINE,
 	GTKAML_ROOT_CLASS_DEFINITION_IMPLEMENTS
 };
+void gtkaml_class_definition_set_source_reference (GtkamlClassDefinition* self, ValaSourceReference* value);
+void gtkaml_class_definition_set_base_ns (GtkamlClassDefinition* self, const char* value);
+void gtkaml_class_definition_set_identifier (GtkamlClassDefinition* self, const char* value);
+void gtkaml_class_definition_set_base_type (GtkamlClassDefinition* self, ValaClass* value);
+GType definition_scope_get_type (void);
+void gtkaml_class_definition_set_definition_scope (GtkamlClassDefinition* self, DefinitionScope value);
+void gtkaml_class_definition_set_parent_container (GtkamlClassDefinition* self, GtkamlClassDefinition* value);
+GType gtkaml_attribute_get_type (void);
+void gtkaml_class_definition_set_attrs (GtkamlClassDefinition* self, GeeList* value);
+GType gtkaml_method_get_type (void);
+GType gtkaml_construct_method_get_type (void);
+void gtkaml_class_definition_set_construct_method (GtkamlClassDefinition* self, GtkamlConstructMethod* value);
+void gtkaml_class_definition_set_children (GtkamlClassDefinition* self, GeeList* value);
+void gtkaml_class_definition_set_construct_code (GtkamlClassDefinition* self, const char* value);
+void gtkaml_class_definition_set_preconstruct_code (GtkamlClassDefinition* self, const char* value);
+void gtkaml_root_class_definition_set_target_name (GtkamlRootClassDefinition* self, const char* value);
+void gtkaml_root_class_definition_set_target_namespace (GtkamlRootClassDefinition* self, const char* value);
+void gtkaml_root_class_definition_set_code (GtkamlRootClassDefinition* self, GeeList* value);
+void gtkaml_root_class_definition_set_implements (GtkamlRootClassDefinition* self, const char* value);
+void gtkaml_root_class_definition_set_original_first_code_line (GtkamlRootClassDefinition* self, gint value);
+GtkamlRootClassDefinition* gtkaml_root_class_definition_new (ValaSourceReference* source_reference, const char* identifier, const char* base_ns, ValaClass* base_type, DefinitionScope definition_scope, GtkamlClassDefinition* parent_container);
+GtkamlRootClassDefinition* gtkaml_root_class_definition_construct (GType object_type, ValaSourceReference* source_reference, const char* identifier, const char* base_ns, ValaClass* base_type, DefinitionScope definition_scope, GtkamlClassDefinition* parent_container);
+GtkamlRootClassDefinition* gtkaml_root_class_definition_new (ValaSourceReference* source_reference, const char* identifier, const char* base_ns, ValaClass* base_type, DefinitionScope definition_scope, GtkamlClassDefinition* parent_container);
+GeeMap* gtkaml_root_class_definition_get_prefixes_namespaces (GtkamlRootClassDefinition* self);
+void gtkaml_root_class_definition_set_prefixes_namespaces (GtkamlRootClassDefinition* self, GeeMap* value);
+const char* gtkaml_root_class_definition_get_target_name (GtkamlRootClassDefinition* self);
+const char* gtkaml_root_class_definition_get_target_namespace (GtkamlRootClassDefinition* self);
+GeeList* gtkaml_root_class_definition_get_code (GtkamlRootClassDefinition* self);
+gint gtkaml_root_class_definition_get_original_first_code_line (GtkamlRootClassDefinition* self);
+const char* gtkaml_root_class_definition_get_implements (GtkamlRootClassDefinition* self);
 static gpointer gtkaml_root_class_definition_parent_class = NULL;
 static void gtkaml_root_class_definition_finalize (GObject* obj);
 
