@@ -20,34 +20,146 @@
  *        Vlad Grecescu (b100dian@gmail.com)
  */
 
-#include "GtkamlSAXParser.h"
-#include <gee/hashmap.h>
-#include <gee/map.h>
+#include <glib.h>
+#include <glib-object.h>
+#include <stdlib.h>
+#include <string.h>
+#include <vala.h>
+#include <gee.h>
 #include <glib/gstdio.h>
-#include <vala/valareport.h>
-#include <gee/arraylist.h>
-#include <gee/collection.h>
 #include <config.h>
-#include <gee/iterable.h>
-#include <gee/iterator.h>
-#include <vala/valausingdirective.h>
-#include <vala/valaunresolvedsymbol.h>
-#include <vala/valasymbol.h>
-#include <vala/valanamespace.h>
-#include <vala/valascope.h>
-#include "GtkamlStateStack.h"
-#include "GtkamlState.h"
-#include "GtkamlAttribute.h"
-#include "GtkamlXmlAttribute.h"
-#include "GtkamlXmlNamespace.h"
-#include "GtkamlSimpleAttribute.h"
-#include "GtkamlReferenceClassDefinition.h"
-#include "GtkamlComplexAttribute.h"
 
 
+#define GTKAML_TYPE_SAX_PARSER (gtkaml_sax_parser_get_type ())
+#define GTKAML_SAX_PARSER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_SAX_PARSER, GtkamlSAXParser))
+#define GTKAML_SAX_PARSER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_SAX_PARSER, GtkamlSAXParserClass))
+#define GTKAML_IS_SAX_PARSER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_SAX_PARSER))
+#define GTKAML_IS_SAX_PARSER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_SAX_PARSER))
+#define GTKAML_SAX_PARSER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_SAX_PARSER, GtkamlSAXParserClass))
 
+typedef struct _GtkamlSAXParser GtkamlSAXParser;
+typedef struct _GtkamlSAXParserClass GtkamlSAXParserClass;
+typedef struct _GtkamlSAXParserPrivate GtkamlSAXParserPrivate;
+
+#define GTKAML_TYPE_CLASS_DEFINITION (gtkaml_class_definition_get_type ())
+#define GTKAML_CLASS_DEFINITION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_CLASS_DEFINITION, GtkamlClassDefinition))
+#define GTKAML_CLASS_DEFINITION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_CLASS_DEFINITION, GtkamlClassDefinitionClass))
+#define GTKAML_IS_CLASS_DEFINITION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_CLASS_DEFINITION))
+#define GTKAML_IS_CLASS_DEFINITION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_CLASS_DEFINITION))
+#define GTKAML_CLASS_DEFINITION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_CLASS_DEFINITION, GtkamlClassDefinitionClass))
+
+typedef struct _GtkamlClassDefinition GtkamlClassDefinition;
+typedef struct _GtkamlClassDefinitionClass GtkamlClassDefinitionClass;
+
+#define GTKAML_TYPE_ROOT_CLASS_DEFINITION (gtkaml_root_class_definition_get_type ())
+#define GTKAML_ROOT_CLASS_DEFINITION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_ROOT_CLASS_DEFINITION, GtkamlRootClassDefinition))
+#define GTKAML_ROOT_CLASS_DEFINITION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_ROOT_CLASS_DEFINITION, GtkamlRootClassDefinitionClass))
+#define GTKAML_IS_ROOT_CLASS_DEFINITION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_ROOT_CLASS_DEFINITION))
+#define GTKAML_IS_ROOT_CLASS_DEFINITION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_ROOT_CLASS_DEFINITION))
+#define GTKAML_ROOT_CLASS_DEFINITION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_ROOT_CLASS_DEFINITION, GtkamlRootClassDefinitionClass))
+
+typedef struct _GtkamlRootClassDefinition GtkamlRootClassDefinition;
+typedef struct _GtkamlRootClassDefinitionClass GtkamlRootClassDefinitionClass;
+
+#define GTKAML_TYPE_STATE_STACK (gtkaml_state_stack_get_type ())
+#define GTKAML_STATE_STACK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_STATE_STACK, GtkamlStateStack))
+#define GTKAML_STATE_STACK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_STATE_STACK, GtkamlStateStackClass))
+#define GTKAML_IS_STATE_STACK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_STATE_STACK))
+#define GTKAML_IS_STATE_STACK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_STATE_STACK))
+#define GTKAML_STATE_STACK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_STATE_STACK, GtkamlStateStackClass))
+
+typedef struct _GtkamlStateStack GtkamlStateStack;
+typedef struct _GtkamlStateStackClass GtkamlStateStackClass;
+
+#define GTKAML_TYPE_STATE_ID (gtkaml_state_id_get_type ())
+
+#define GTKAML_TYPE_ATTRIBUTE (gtkaml_attribute_get_type ())
+#define GTKAML_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_ATTRIBUTE, GtkamlAttribute))
+#define GTKAML_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_ATTRIBUTE, GtkamlAttributeClass))
+#define GTKAML_IS_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_ATTRIBUTE))
+#define GTKAML_IS_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_ATTRIBUTE))
+#define GTKAML_ATTRIBUTE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_ATTRIBUTE, GtkamlAttributeClass))
+
+typedef struct _GtkamlAttribute GtkamlAttribute;
+typedef struct _GtkamlAttributeClass GtkamlAttributeClass;
+
+#define GTKAML_TYPE_STATE (gtkaml_state_get_type ())
+#define GTKAML_STATE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_STATE, GtkamlState))
+#define GTKAML_STATE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_STATE, GtkamlStateClass))
+#define GTKAML_IS_STATE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_STATE))
+#define GTKAML_IS_STATE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_STATE))
+#define GTKAML_STATE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_STATE, GtkamlStateClass))
+
+typedef struct _GtkamlState GtkamlState;
+typedef struct _GtkamlStateClass GtkamlStateClass;
+
+#define GTKAML_TYPE_XML_ATTRIBUTE (gtkaml_xml_attribute_get_type ())
+#define GTKAML_XML_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_XML_ATTRIBUTE, GtkamlXmlAttribute))
+#define GTKAML_XML_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_XML_ATTRIBUTE, GtkamlXmlAttributeClass))
+#define GTKAML_IS_XML_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_XML_ATTRIBUTE))
+#define GTKAML_IS_XML_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_XML_ATTRIBUTE))
+#define GTKAML_XML_ATTRIBUTE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_XML_ATTRIBUTE, GtkamlXmlAttributeClass))
+
+typedef struct _GtkamlXmlAttribute GtkamlXmlAttribute;
+typedef struct _GtkamlXmlAttributeClass GtkamlXmlAttributeClass;
+
+#define TYPE_XML_NAMESPACE (xml_namespace_get_type ())
+#define XML_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_XML_NAMESPACE, XmlNamespace))
+#define XML_NAMESPACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_XML_NAMESPACE, XmlNamespaceClass))
+#define IS_XML_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_XML_NAMESPACE))
+#define IS_XML_NAMESPACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_XML_NAMESPACE))
+#define XML_NAMESPACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_XML_NAMESPACE, XmlNamespaceClass))
+
+typedef struct _XmlNamespace XmlNamespace;
+typedef struct _XmlNamespaceClass XmlNamespaceClass;
+typedef struct _XmlNamespacePrivate XmlNamespacePrivate;
+
+#define GTKAML_TYPE_COMPLEX_ATTRIBUTE (gtkaml_complex_attribute_get_type ())
+#define GTKAML_COMPLEX_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_COMPLEX_ATTRIBUTE, GtkamlComplexAttribute))
+#define GTKAML_COMPLEX_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_COMPLEX_ATTRIBUTE, GtkamlComplexAttributeClass))
+#define GTKAML_IS_COMPLEX_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_COMPLEX_ATTRIBUTE))
+#define GTKAML_IS_COMPLEX_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_COMPLEX_ATTRIBUTE))
+#define GTKAML_COMPLEX_ATTRIBUTE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_COMPLEX_ATTRIBUTE, GtkamlComplexAttributeClass))
+
+typedef struct _GtkamlComplexAttribute GtkamlComplexAttribute;
+typedef struct _GtkamlComplexAttributeClass GtkamlComplexAttributeClass;
+
+#define GTKAML_TYPE_SIMPLE_ATTRIBUTE (gtkaml_simple_attribute_get_type ())
+#define GTKAML_SIMPLE_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_SIMPLE_ATTRIBUTE, GtkamlSimpleAttribute))
+#define GTKAML_SIMPLE_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_SIMPLE_ATTRIBUTE, GtkamlSimpleAttributeClass))
+#define GTKAML_IS_SIMPLE_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_SIMPLE_ATTRIBUTE))
+#define GTKAML_IS_SIMPLE_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_SIMPLE_ATTRIBUTE))
+#define GTKAML_SIMPLE_ATTRIBUTE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_SIMPLE_ATTRIBUTE, GtkamlSimpleAttributeClass))
+
+typedef struct _GtkamlSimpleAttribute GtkamlSimpleAttribute;
+typedef struct _GtkamlSimpleAttributeClass GtkamlSimpleAttributeClass;
+
+#define TYPE_DEFINITION_SCOPE (definition_scope_get_type ())
+typedef struct _GtkamlXmlAttributePrivate GtkamlXmlAttributePrivate;
+
+#define GTKAML_TYPE_REFERENCE_CLASS_DEFINITION (gtkaml_reference_class_definition_get_type ())
+#define GTKAML_REFERENCE_CLASS_DEFINITION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_REFERENCE_CLASS_DEFINITION, GtkamlReferenceClassDefinition))
+#define GTKAML_REFERENCE_CLASS_DEFINITION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_REFERENCE_CLASS_DEFINITION, GtkamlReferenceClassDefinitionClass))
+#define GTKAML_IS_REFERENCE_CLASS_DEFINITION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_REFERENCE_CLASS_DEFINITION))
+#define GTKAML_IS_REFERENCE_CLASS_DEFINITION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_REFERENCE_CLASS_DEFINITION))
+#define GTKAML_REFERENCE_CLASS_DEFINITION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_REFERENCE_CLASS_DEFINITION, GtkamlReferenceClassDefinitionClass))
+
+typedef struct _GtkamlReferenceClassDefinition GtkamlReferenceClassDefinition;
+typedef struct _GtkamlReferenceClassDefinitionClass GtkamlReferenceClassDefinitionClass;
+
+/** this is the Flying Spaghetti Monster */
+struct _GtkamlSAXParser {
+	GObject parent_instance;
+	GtkamlSAXParserPrivate * priv;
+	void* xmlCtxt;
+	char* gtkaml_prefix;
+};
+
+struct _GtkamlSAXParserClass {
+	GObjectClass parent_class;
+	GtkamlRootClassDefinition* (*parse) (GtkamlSAXParser* self);
+};
 
-static char* string_substring (const char* self, glong offset, glong len);
 struct _GtkamlSAXParserPrivate {
 	ValaCodeContext* _context;
 	ValaSourceFile* _source_file;
@@ -57,27 +169,148 @@ struct _GtkamlSAXParserPrivate {
 	GtkamlRootClassDefinition* _root_class_definition;
 };
 
+typedef enum  {
+	GTKAML_STATE_ID_SAX_PARSER_INITIAL_STATE = 0,
+	GTKAML_STATE_ID_SAX_PARSER_CONTAINER_STATE,
+	GTKAML_STATE_ID_SAX_PARSER_ATTRIBUTE_STATE
+} GtkamlStateId;
+
+/**
+ * an xml namespace, often referred to as 'prefix'
+ */
+struct _XmlNamespace {
+	GObject parent_instance;
+	XmlNamespacePrivate * priv;
+	char* prefix;
+	char* URI;
+};
+
+struct _XmlNamespaceClass {
+	GObjectClass parent_class;
+};
+
+typedef enum  {
+	DEFINITION_SCOPE_MAIN_CLASS = 0,
+	DEFINITION_SCOPE_PUBLIC,
+	DEFINITION_SCOPE_PRIVATE,
+	DEFINITION_SCOPE_CONSTRUCTOR
+} DefinitionScope;
+
+/**
+ * an attribute as presented by libxml2
+ */
+struct _GtkamlXmlAttribute {
+	GObject parent_instance;
+	GtkamlXmlAttributePrivate * priv;
+	char* localname;
+	char* prefix;
+	char* URI;
+	char* value;
+};
+
+struct _GtkamlXmlAttributeClass {
+	GObjectClass parent_class;
+};
+
+
+
+GType gtkaml_sax_parser_get_type (void);
+GType gtkaml_class_definition_get_type (void);
+GType gtkaml_root_class_definition_get_type (void);
+GType gtkaml_state_stack_get_type (void);
 #define GTKAML_SAX_PARSER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GTKAML_TYPE_SAX_PARSER, GtkamlSAXParserPrivate))
 enum  {
 	GTKAML_SAX_PARSER_DUMMY_PROPERTY,
 	GTKAML_SAX_PARSER_CONTEXT,
 	GTKAML_SAX_PARSER_SOURCE_FILE
 };
-static GtkamlRootClassDefinition* gtkaml_sax_parser_real_parse (GtkamlSAXParser* self);
-static void gtkaml_sax_parser_parse_attribute_content_as_text (GtkamlSAXParser* self, GtkamlState* state, const char* content);
-static char* gtkaml_sax_parser_prefix_to_namespace (GtkamlSAXParser* self, const char* prefix);
-static ValaClass* gtkaml_sax_parser_lookup_class (GtkamlSAXParser* self, const char* xmlNamespace, const char* name);
-static char* gtkaml_sax_parser_strip_attribute_hyphens (GtkamlSAXParser* self, const char* attrname);
-static GeeList* gtkaml_sax_parser_parse_attributes (GtkamlSAXParser* self, char** attributes, gint nb_attributes);
-static GeeList* gtkaml_sax_parser_parse_namespaces (GtkamlSAXParser* self, char** namespaces, gint nb_namespaces);
 static void gtkaml_sax_parser_set_context (GtkamlSAXParser* self, ValaCodeContext* value);
 static void gtkaml_sax_parser_set_source_file (GtkamlSAXParser* self, ValaSourceFile* value);
+GtkamlSAXParser* gtkaml_sax_parser_new (ValaCodeContext* context, ValaSourceFile* source_file);
+GtkamlSAXParser* gtkaml_sax_parser_construct (GType object_type, ValaCodeContext* context, ValaSourceFile* source_file);
+GtkamlSAXParser* gtkaml_sax_parser_new (ValaCodeContext* context, ValaSourceFile* source_file);
+ValaSourceFile* gtkaml_sax_parser_get_source_file (GtkamlSAXParser* self);
+GType gtkaml_state_id_get_type (void);
+GType gtkaml_attribute_get_type (void);
+GtkamlState* gtkaml_state_new (GtkamlStateId state_id, GtkamlClassDefinition* class_definition, GtkamlAttribute* attribute, const char* attribute_name);
+GtkamlState* gtkaml_state_construct (GType object_type, GtkamlStateId state_id, GtkamlClassDefinition* class_definition, GtkamlAttribute* attribute, const char* attribute_name);
+GType gtkaml_state_get_type (void);
 static GtkamlStateStack* gtkaml_sax_parser_get_states (GtkamlSAXParser* self);
-static void gtkaml_sax_parser_set_states (GtkamlSAXParser* self, GtkamlStateStack* value);
-static GeeMap* gtkaml_sax_parser_get_prefixes_namespaces (GtkamlSAXParser* self);
-static void gtkaml_sax_parser_set_prefixes_namespaces (GtkamlSAXParser* self, GeeMap* value);
+void gtkaml_state_stack_push (GtkamlStateStack* self, GtkamlState* element);
+void gtkaml_sax_parser_start_parsing (GtkamlSAXParser* self, const char* contents, gulong length);
 static GtkamlRootClassDefinition* gtkaml_sax_parser_get_root_class_definition (GtkamlSAXParser* self);
+GtkamlRootClassDefinition* gtkaml_sax_parser_parse (GtkamlSAXParser* self);
+static GtkamlRootClassDefinition* gtkaml_sax_parser_real_parse (GtkamlSAXParser* self);
+void gtkaml_sax_parser_stop_parsing (GtkamlSAXParser* self);
+gint gtkaml_sax_parser_column_number (GtkamlSAXParser* self);
+gint gtkaml_sax_parser_line_number (GtkamlSAXParser* self);
+GType gtkaml_xml_attribute_get_type (void);
+static GeeList* gtkaml_sax_parser_parse_attributes (GtkamlSAXParser* self, char** attributes, gint nb_attributes);
+GtkamlState* gtkaml_state_stack_peek (GtkamlStateStack* self, gint backtrack);
+ValaSourceReference* gtkaml_sax_parser_create_source_reference (GtkamlSAXParser* self);
+GtkamlStateId gtkaml_state_get_state_id (GtkamlState* self);
+GType xml_namespace_get_type (void);
+static GeeList* gtkaml_sax_parser_parse_namespaces (GtkamlSAXParser* self, char** namespaces, gint nb_namespaces);
+static GeeMap* gtkaml_sax_parser_get_prefixes_namespaces (GtkamlSAXParser* self);
+static ValaClass* gtkaml_sax_parser_lookup_class (GtkamlSAXParser* self, const char* xmlNamespace, const char* name);
+static char* gtkaml_sax_parser_prefix_to_namespace (GtkamlSAXParser* self, const char* prefix);
+GtkamlRootClassDefinition* gtkaml_sax_parser_get_root_definition (GtkamlSAXParser* self, ValaClass* clazz, GeeList* attrs, const char* prefix);
 static void gtkaml_sax_parser_set_root_class_definition (GtkamlSAXParser* self, GtkamlRootClassDefinition* value);
+GtkamlClassDefinition* gtkaml_sax_parser_get_child_for_container (GtkamlSAXParser* self, ValaClass* clazz, GtkamlClassDefinition* container_definition, GeeList* attrs, const char* prefix);
+GtkamlClassDefinition* gtkaml_state_get_class_definition (GtkamlState* self);
+GtkamlAttribute* gtkaml_state_get_attribute (GtkamlState* self);
+const char* gtkaml_state_get_attribute_name (GtkamlState* self);
+static char* gtkaml_sax_parser_strip_attribute_hyphens (GtkamlSAXParser* self, const char* attrname);
+GtkamlComplexAttribute* gtkaml_complex_attribute_new (const char* name, GtkamlClassDefinition* complex_type);
+GtkamlComplexAttribute* gtkaml_complex_attribute_construct (GType object_type, const char* name, GtkamlClassDefinition* complex_type);
+GType gtkaml_complex_attribute_get_type (void);
+void gtkaml_state_set_attribute (GtkamlState* self, GtkamlAttribute* value);
+void gtkaml_class_definition_add_attribute (GtkamlClassDefinition* self, GtkamlAttribute* attr);
+void gtkaml_sax_parser_start_element (GtkamlSAXParser* self, const char* localname, const char* prefix, const char* URI, gint nb_namespaces, char** namespaces, gint nb_attributes, gint nb_defaulted, char** attributes);
+static void gtkaml_sax_parser_parse_attribute_content_as_text (GtkamlSAXParser* self, GtkamlState* state, const char* content);
+void gtkaml_sax_parser_characters (GtkamlSAXParser* self, const char* data, gint len);
+GtkamlState* gtkaml_state_stack_pop (GtkamlStateStack* self);
+char* gtkaml_class_definition_get_base_full_name (GtkamlClassDefinition* self);
+void gtkaml_sax_parser_end_element (GtkamlSAXParser* self, const char* localname, const char* prefix, const char* URI);
+gint gtkaml_root_class_definition_get_original_first_code_line (GtkamlRootClassDefinition* self);
+void gtkaml_root_class_definition_set_original_first_code_line (GtkamlRootClassDefinition* self, gint value);
+GeeList* gtkaml_root_class_definition_get_code (GtkamlRootClassDefinition* self);
+void gtkaml_sax_parser_cdata_block (GtkamlSAXParser* self, const char* cdata, gint len);
+const char* gtkaml_class_definition_get_preconstruct_code (GtkamlClassDefinition* self);
+const char* gtkaml_class_definition_get_identifier (GtkamlClassDefinition* self);
+void gtkaml_class_definition_set_preconstruct_code (GtkamlClassDefinition* self, const char* value);
+const char* gtkaml_class_definition_get_construct_code (GtkamlClassDefinition* self);
+void gtkaml_class_definition_set_construct_code (GtkamlClassDefinition* self, const char* value);
+GtkamlSimpleAttribute* gtkaml_simple_attribute_new (const char* name, const char* value);
+GtkamlSimpleAttribute* gtkaml_simple_attribute_construct (GType object_type, const char* name, const char* value);
+GType gtkaml_simple_attribute_get_type (void);
+const char* gtkaml_simple_attribute_get_value (GtkamlSimpleAttribute* self);
+void gtkaml_simple_attribute_set_value (GtkamlSimpleAttribute* self, const char* value);
+const char* gtkaml_attribute_get_name (GtkamlAttribute* self);
+ValaCodeContext* gtkaml_sax_parser_get_context (GtkamlSAXParser* self);
+GType definition_scope_get_type (void);
+GtkamlRootClassDefinition* gtkaml_root_class_definition_new (ValaSourceReference* source_reference, const char* identifier, const char* base_ns, ValaClass* base_type, DefinitionScope definition_scope, GtkamlClassDefinition* parent_container);
+GtkamlRootClassDefinition* gtkaml_root_class_definition_construct (GType object_type, ValaSourceReference* source_reference, const char* identifier, const char* base_ns, ValaClass* base_type, DefinitionScope definition_scope, GtkamlClassDefinition* parent_container);
+void gtkaml_root_class_definition_set_prefixes_namespaces (GtkamlRootClassDefinition* self, GeeMap* value);
+const char* gtkaml_root_class_definition_get_target_name (GtkamlRootClassDefinition* self);
+void gtkaml_root_class_definition_set_target_name (GtkamlRootClassDefinition* self, const char* value);
+void gtkaml_root_class_definition_set_target_namespace (GtkamlRootClassDefinition* self, const char* value);
+void gtkaml_root_class_definition_set_implements (GtkamlRootClassDefinition* self, const char* value);
+GtkamlClassDefinition* gtkaml_class_definition_new (ValaSourceReference* source_reference, const char* identifier, const char* base_ns, ValaClass* base_type, DefinitionScope definition_scope, GtkamlClassDefinition* parent_container);
+GtkamlClassDefinition* gtkaml_class_definition_construct (GType object_type, ValaSourceReference* source_reference, const char* identifier, const char* base_ns, ValaClass* base_type, DefinitionScope definition_scope, GtkamlClassDefinition* parent_container);
+GtkamlReferenceClassDefinition* gtkaml_reference_class_definition_new (ValaSourceReference* source_reference, const char* reference, const char* base_ns, ValaClass* base_type, GtkamlClassDefinition* parent_container);
+GtkamlReferenceClassDefinition* gtkaml_reference_class_definition_construct (GType object_type, ValaSourceReference* source_reference, const char* reference, const char* base_ns, ValaClass* base_type, GtkamlClassDefinition* parent_container);
+GType gtkaml_reference_class_definition_get_type (void);
+void gtkaml_class_definition_set_identifier (GtkamlClassDefinition* self, const char* value);
+void gtkaml_class_definition_add_child (GtkamlClassDefinition* self, GtkamlClassDefinition* child);
+GtkamlXmlAttribute* gtkaml_xml_attribute_new (void);
+GtkamlXmlAttribute* gtkaml_xml_attribute_construct (GType object_type);
+XmlNamespace* xml_namespace_new (void);
+XmlNamespace* xml_namespace_construct (GType object_type);
+static void gtkaml_sax_parser_set_states (GtkamlSAXParser* self, GtkamlStateStack* value);
+static void gtkaml_sax_parser_set_prefixes_namespaces (GtkamlSAXParser* self, GeeMap* value);
+GtkamlStateStack* gtkaml_state_stack_new (void);
+GtkamlStateStack* gtkaml_state_stack_construct (GType object_type);
 static GObject * gtkaml_sax_parser_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer gtkaml_sax_parser_parent_class = NULL;
 static void gtkaml_sax_parser_finalize (GObject* obj);
@@ -87,26 +320,6 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 
-static char* string_substring (const char* self, glong offset, glong len) {
-	glong string_length;
-	const char* start;
-	g_return_val_if_fail (self != NULL, NULL);
-	string_length = g_utf8_strlen (self, -1);
-	if (offset < 0) {
-		offset = string_length + offset;
-		g_return_val_if_fail (offset >= 0, NULL);
-	} else {
-		g_return_val_if_fail (offset <= string_length, NULL);
-	}
-	if (len < 0) {
-		len = string_length - offset;
-	}
-	g_return_val_if_fail ((offset + len) <= string_length, NULL);
-	start = g_utf8_offset_to_pointer (self, offset);
-	return g_strndup (start, ((gchar*) g_utf8_offset_to_pointer (start, len)) - ((gchar*) start));
-}
-
-
 GtkamlSAXParser* gtkaml_sax_parser_construct (GType object_type, ValaCodeContext* context, ValaSourceFile* source_file) {
 	GtkamlSAXParser * self;
 	g_return_val_if_fail (context != NULL, NULL);
@@ -197,11 +410,11 @@ void gtkaml_sax_parser_start_element (GtkamlSAXParser* self, const char* localna
 		{
 			{
 				GeeList* nss;
-				char* _tmp5;
-				ValaClass* _tmp6;
+				char* _tmp6;
+				ValaClass* _tmp7;
 				ValaClass* clazz;
-				GtkamlRootClassDefinition* _tmp8;
-				GtkamlState* _tmp9;
+				GtkamlRootClassDefinition* _tmp9;
+				GtkamlState* _tmp10;
 				/*Frist Tag! - that means, add "using" directives first*/
 				nss = gtkaml_sax_parser_parse_namespaces (self, namespaces, nb_namespaces);
 				{
@@ -225,18 +438,20 @@ void gtkaml_sax_parser_start_element (GtkamlSAXParser* self, const char* localna
 							_tmp0 = _tmp1;
 						}
 						if (_tmp0) {
-							char** _tmp2;
+							char** _tmp3;
 							gint uri_definition_size;
 							gint uri_definition_length1;
+							char** _tmp2;
 							char** uri_definition;
-							ValaUnresolvedSymbol* _tmp3;
-							ValaUsingDirective* _tmp4;
+							ValaUnresolvedSymbol* _tmp4;
+							ValaUsingDirective* _tmp5;
 							ValaUsingDirective* namespace_reference;
-							_tmp2 = NULL;
-							uri_definition = (_tmp2 = g_strsplit_set (ns->URI, ":", 0), uri_definition_length1 = -1, uri_definition_size = uri_definition_length1, _tmp2);
 							_tmp3 = NULL;
+							_tmp2 = NULL;
+							uri_definition = (_tmp3 = _tmp2 = g_strsplit_set (ns->URI, ":", 0), uri_definition_length1 = _vala_array_length (_tmp2), uri_definition_size = uri_definition_length1, _tmp3);
 							_tmp4 = NULL;
-							namespace_reference = (_tmp4 = vala_using_directive_new ((ValaSymbol*) (_tmp3 = vala_unresolved_symbol_new (NULL, "GLib", NULL)), source_reference), (_tmp3 == NULL) ? NULL : (_tmp3 = (vala_code_node_unref (_tmp3), NULL)), _tmp4);
+							_tmp5 = NULL;
+							namespace_reference = (_tmp5 = vala_using_directive_new ((ValaSymbol*) (_tmp4 = vala_unresolved_symbol_new (NULL, "GLib", NULL)), source_reference), (_tmp4 == NULL) ? NULL : (_tmp4 = (vala_code_node_unref (_tmp4), NULL)), _tmp5);
 							vala_source_file_add_using_directive (self->priv->_source_file, namespace_reference);
 							if (NULL == ns->prefix) {
 								/*stderr.printf ("adding '%s':'%s' to prefixes_namespaces map\n", "", uri_definition[0]);*/
@@ -252,14 +467,14 @@ void gtkaml_sax_parser_start_element (GtkamlSAXParser* self, const char* localna
 					}
 					(_ns_it == NULL) ? NULL : (_ns_it = (gee_collection_object_unref (_ns_it), NULL));
 				}
-				_tmp5 = NULL;
 				_tmp6 = NULL;
-				clazz = (_tmp6 = gtkaml_sax_parser_lookup_class (self, _tmp5 = gtkaml_sax_parser_prefix_to_namespace (self, prefix), localname), _tmp5 = (g_free (_tmp5), NULL), _tmp6);
+				_tmp7 = NULL;
+				clazz = (_tmp7 = gtkaml_sax_parser_lookup_class (self, _tmp6 = gtkaml_sax_parser_prefix_to_namespace (self, prefix), localname), _tmp6 = (g_free (_tmp6), NULL), _tmp7);
 				if (clazz == NULL) {
-					char* _tmp7;
-					_tmp7 = NULL;
-					vala_report_error (source_reference, _tmp7 = g_strdup_printf ("%s not a class", localname));
-					_tmp7 = (g_free (_tmp7), NULL);
+					char* _tmp8;
+					_tmp8 = NULL;
+					vala_report_error (source_reference, _tmp8 = g_strdup_printf ("%s not a class", localname));
+					_tmp8 = (g_free (_tmp8), NULL);
 					gtkaml_sax_parser_stop_parsing (self);
 					(nss == NULL) ? NULL : (nss = (gee_collection_object_unref (nss), NULL));
 					(clazz == NULL) ? NULL : (clazz = (vala_code_node_unref (clazz), NULL));
@@ -268,12 +483,12 @@ void gtkaml_sax_parser_start_element (GtkamlSAXParser* self, const char* localna
 					(source_reference == NULL) ? NULL : (source_reference = (vala_source_reference_unref (source_reference), NULL));
 					return;
 				}
-				_tmp8 = NULL;
-				gtkaml_sax_parser_set_root_class_definition (self, _tmp8 = gtkaml_sax_parser_get_root_definition (self, clazz, attrs, prefix));
-				(_tmp8 == NULL) ? NULL : (_tmp8 = (g_object_unref (_tmp8), NULL));
 				_tmp9 = NULL;
-				gtkaml_state_stack_push (self->priv->_states, _tmp9 = gtkaml_state_new (GTKAML_STATE_ID_SAX_PARSER_CONTAINER_STATE, (GtkamlClassDefinition*) self->priv->_root_class_definition, NULL, NULL));
+				gtkaml_sax_parser_set_root_class_definition (self, _tmp9 = gtkaml_sax_parser_get_root_definition (self, clazz, attrs, prefix));
 				(_tmp9 == NULL) ? NULL : (_tmp9 = (g_object_unref (_tmp9), NULL));
+				_tmp10 = NULL;
+				gtkaml_state_stack_push (self->priv->_states, _tmp10 = gtkaml_state_new (GTKAML_STATE_ID_SAX_PARSER_CONTAINER_STATE, (GtkamlClassDefinition*) self->priv->_root_class_definition, NULL, NULL));
+				(_tmp10 == NULL) ? NULL : (_tmp10 = (g_object_unref (_tmp10), NULL));
 				(nss == NULL) ? NULL : (nss = (gee_collection_object_unref (nss), NULL));
 				(clazz == NULL) ? NULL : (clazz = (vala_code_node_unref (clazz), NULL));
 				break;
@@ -282,54 +497,54 @@ void gtkaml_sax_parser_start_element (GtkamlSAXParser* self, const char* localna
 		case GTKAML_STATE_ID_SAX_PARSER_CONTAINER_STATE:
 		{
 			{
-				char* _tmp10;
-				ValaClass* _tmp11;
+				char* _tmp11;
+				ValaClass* _tmp12;
 				ValaClass* clazz;
 				char* fqan;
-				_tmp10 = NULL;
 				_tmp11 = NULL;
-				clazz = (_tmp11 = gtkaml_sax_parser_lookup_class (self, _tmp10 = gtkaml_sax_parser_prefix_to_namespace (self, prefix), localname), _tmp10 = (g_free (_tmp10), NULL), _tmp11);
+				_tmp12 = NULL;
+				clazz = (_tmp12 = gtkaml_sax_parser_lookup_class (self, _tmp11 = gtkaml_sax_parser_prefix_to_namespace (self, prefix), localname), _tmp11 = (g_free (_tmp11), NULL), _tmp12);
 				fqan = NULL;
 				if (clazz != NULL) {
 					GtkamlClassDefinition* class_definition;
-					GtkamlState* _tmp12;
+					GtkamlState* _tmp13;
 					/*this is a member/container child object*/
 					class_definition = gtkaml_sax_parser_get_child_for_container (self, clazz, gtkaml_state_get_class_definition (state), attrs, prefix);
-					_tmp12 = NULL;
-					gtkaml_state_stack_push (self->priv->_states, _tmp12 = gtkaml_state_new (GTKAML_STATE_ID_SAX_PARSER_CONTAINER_STATE, class_definition, NULL, NULL));
-					(_tmp12 == NULL) ? NULL : (_tmp12 = (g_object_unref (_tmp12), NULL));
+					_tmp13 = NULL;
+					gtkaml_state_stack_push (self->priv->_states, _tmp13 = gtkaml_state_new (GTKAML_STATE_ID_SAX_PARSER_CONTAINER_STATE, class_definition, NULL, NULL));
+					(_tmp13 == NULL) ? NULL : (_tmp13 = (g_object_unref (_tmp13), NULL));
 					(class_definition == NULL) ? NULL : (class_definition = (g_object_unref (class_definition), NULL));
 				} else {
-					GtkamlClassDefinition* _tmp13;
+					GtkamlClassDefinition* _tmp14;
 					GtkamlClassDefinition* attribute_parent_class_definition;
-					GtkamlState* _tmp19;
+					GtkamlState* _tmp20;
 					/*no class with this name found, assume it's an attribute*/
-					_tmp13 = NULL;
-					attribute_parent_class_definition = (_tmp13 = gtkaml_state_get_class_definition (state), (_tmp13 == NULL) ? NULL : g_object_ref (_tmp13));
+					_tmp14 = NULL;
+					attribute_parent_class_definition = (_tmp14 = gtkaml_state_get_class_definition (state), (_tmp14 == NULL) ? NULL : g_object_ref (_tmp14));
 					if (prefix != NULL) {
+						char* _tmp16;
 						char* _tmp15;
-						char* _tmp14;
-						_tmp15 = NULL;
-						_tmp14 = NULL;
-						fqan = (_tmp15 = g_strconcat (_tmp14 = g_strconcat (prefix, ".", NULL), localname, NULL), fqan = (g_free (fqan), NULL), _tmp15);
-						_tmp14 = (g_free (_tmp14), NULL);
-					} else {
-						char* _tmp17;
-						const char* _tmp16;
-						_tmp17 = NULL;
 						_tmp16 = NULL;
-						fqan = (_tmp17 = (_tmp16 = localname, (_tmp16 == NULL) ? NULL : g_strdup (_tmp16)), fqan = (g_free (fqan), NULL), _tmp17);
+						_tmp15 = NULL;
+						fqan = (_tmp16 = g_strconcat (_tmp15 = g_strconcat (prefix, ".", NULL), localname, NULL), fqan = (g_free (fqan), NULL), _tmp16);
+						_tmp15 = (g_free (_tmp15), NULL);
+					} else {
+						char* _tmp18;
+						const char* _tmp17;
+						_tmp18 = NULL;
+						_tmp17 = NULL;
+						fqan = (_tmp18 = (_tmp17 = localname, (_tmp17 == NULL) ? NULL : g_strdup (_tmp17)), fqan = (g_free (fqan), NULL), _tmp18);
 					}
 					if (gee_collection_get_size ((GeeCollection*) attrs) > 0) {
-						char* _tmp18;
+						char* _tmp19;
 						/*an attribute cannot have.. attributes*/
-						_tmp18 = NULL;
-						vala_report_error (source_reference, _tmp18 = g_strdup_printf ("No class %s found.", fqan));
-						_tmp18 = (g_free (_tmp18), NULL);
+						_tmp19 = NULL;
+						vala_report_error (source_reference, _tmp19 = g_strdup_printf ("No class %s found.", fqan));
+						_tmp19 = (g_free (_tmp19), NULL);
 					}
-					_tmp19 = NULL;
-					gtkaml_state_stack_push (self->priv->_states, _tmp19 = gtkaml_state_new (GTKAML_STATE_ID_SAX_PARSER_ATTRIBUTE_STATE, attribute_parent_class_definition, NULL, fqan));
-					(_tmp19 == NULL) ? NULL : (_tmp19 = (g_object_unref (_tmp19), NULL));
+					_tmp20 = NULL;
+					gtkaml_state_stack_push (self->priv->_states, _tmp20 = gtkaml_state_new (GTKAML_STATE_ID_SAX_PARSER_ATTRIBUTE_STATE, attribute_parent_class_definition, NULL, fqan));
+					(_tmp20 == NULL) ? NULL : (_tmp20 = (g_object_unref (_tmp20), NULL));
 					(attribute_parent_class_definition == NULL) ? NULL : (attribute_parent_class_definition = (g_object_unref (attribute_parent_class_definition), NULL));
 				}
 				(clazz == NULL) ? NULL : (clazz = (vala_code_node_unref (clazz), NULL));
@@ -340,41 +555,41 @@ void gtkaml_sax_parser_start_element (GtkamlSAXParser* self, const char* localna
 		case GTKAML_STATE_ID_SAX_PARSER_ATTRIBUTE_STATE:
 		{
 			{
-				char* _tmp21;
-				ValaClass* _tmp22;
+				char* _tmp22;
+				ValaClass* _tmp23;
 				ValaClass* clazz;
 				GtkamlClassDefinition* attribute_value_definition;
-				char* _tmp25;
-				GtkamlComplexAttribute* _tmp26;
+				char* _tmp26;
+				GtkamlComplexAttribute* _tmp27;
 				GtkamlComplexAttribute* attr;
-				GtkamlState* _tmp27;
+				GtkamlState* _tmp28;
 				/*a tag found within an attribute state switches us to container_state*/
 				if (gtkaml_state_get_attribute (state) != NULL) {
-					char* _tmp20;
+					char* _tmp21;
 					/*this was created by non-discardable text nodes*/
-					_tmp20 = NULL;
-					vala_report_error (source_reference, _tmp20 = g_strdup_printf ("Incorrect attribute definition for %s", gtkaml_state_get_attribute_name (state)));
-					_tmp20 = (g_free (_tmp20), NULL);
+					_tmp21 = NULL;
+					vala_report_error (source_reference, _tmp21 = g_strdup_printf ("Incorrect attribute definition for %s", gtkaml_state_get_attribute_name (state)));
+					_tmp21 = (g_free (_tmp21), NULL);
 					gtkaml_sax_parser_stop_parsing (self);
 					(attrs == NULL) ? NULL : (attrs = (gee_collection_object_unref (attrs), NULL));
 					(state == NULL) ? NULL : (state = (g_object_unref (state), NULL));
 					(source_reference == NULL) ? NULL : (source_reference = (vala_source_reference_unref (source_reference), NULL));
 					return;
 				}
-				_tmp21 = NULL;
 				_tmp22 = NULL;
-				clazz = (_tmp22 = gtkaml_sax_parser_lookup_class (self, _tmp21 = gtkaml_sax_parser_prefix_to_namespace (self, prefix), localname), _tmp21 = (g_free (_tmp21), NULL), _tmp22);
+				_tmp23 = NULL;
+				clazz = (_tmp23 = gtkaml_sax_parser_lookup_class (self, _tmp22 = gtkaml_sax_parser_prefix_to_namespace (self, prefix), localname), _tmp22 = (g_free (_tmp22), NULL), _tmp23);
 				attribute_value_definition = NULL;
 				if (clazz != NULL) {
-					GtkamlClassDefinition* _tmp23;
+					GtkamlClassDefinition* _tmp24;
 					/*this is a member/container child object*/
-					_tmp23 = NULL;
-					attribute_value_definition = (_tmp23 = gtkaml_sax_parser_get_child_for_container (self, clazz, NULL, attrs, prefix), (attribute_value_definition == NULL) ? NULL : (attribute_value_definition = (g_object_unref (attribute_value_definition), NULL)), _tmp23);
-				} else {
-					char* _tmp24;
 					_tmp24 = NULL;
-					vala_report_error (source_reference, _tmp24 = g_strdup_printf ("No class '%s' found", localname));
-					_tmp24 = (g_free (_tmp24), NULL);
+					attribute_value_definition = (_tmp24 = gtkaml_sax_parser_get_child_for_container (self, clazz, NULL, attrs, prefix), (attribute_value_definition == NULL) ? NULL : (attribute_value_definition = (g_object_unref (attribute_value_definition), NULL)), _tmp24);
+				} else {
+					char* _tmp25;
+					_tmp25 = NULL;
+					vala_report_error (source_reference, _tmp25 = g_strdup_printf ("No class '%s' found", localname));
+					_tmp25 = (g_free (_tmp25), NULL);
 					gtkaml_sax_parser_stop_parsing (self);
 					(clazz == NULL) ? NULL : (clazz = (vala_code_node_unref (clazz), NULL));
 					(attribute_value_definition == NULL) ? NULL : (attribute_value_definition = (g_object_unref (attribute_value_definition), NULL));
@@ -383,15 +598,15 @@ void gtkaml_sax_parser_start_element (GtkamlSAXParser* self, const char* localna
 					(source_reference == NULL) ? NULL : (source_reference = (vala_source_reference_unref (source_reference), NULL));
 					return;
 				}
-				_tmp25 = NULL;
 				_tmp26 = NULL;
-				attr = (_tmp26 = gtkaml_complex_attribute_new (_tmp25 = gtkaml_sax_parser_strip_attribute_hyphens (self, gtkaml_state_get_attribute_name (state)), attribute_value_definition), _tmp25 = (g_free (_tmp25), NULL), _tmp26);
+				_tmp27 = NULL;
+				attr = (_tmp27 = gtkaml_complex_attribute_new (_tmp26 = gtkaml_sax_parser_strip_attribute_hyphens (self, gtkaml_state_get_attribute_name (state)), attribute_value_definition), _tmp26 = (g_free (_tmp26), NULL), _tmp27);
 				gtkaml_state_set_attribute (state, (GtkamlAttribute*) attr);
 				/*add the attribute into the parent container*/
 				gtkaml_class_definition_add_attribute (gtkaml_state_get_class_definition (state), (GtkamlAttribute*) attr);
-				_tmp27 = NULL;
-				gtkaml_state_stack_push (self->priv->_states, _tmp27 = gtkaml_state_new (GTKAML_STATE_ID_SAX_PARSER_CONTAINER_STATE, attribute_value_definition, NULL, NULL));
-				(_tmp27 == NULL) ? NULL : (_tmp27 = (g_object_unref (_tmp27), NULL));
+				_tmp28 = NULL;
+				gtkaml_state_stack_push (self->priv->_states, _tmp28 = gtkaml_state_new (GTKAML_STATE_ID_SAX_PARSER_CONTAINER_STATE, attribute_value_definition, NULL, NULL));
+				(_tmp28 == NULL) ? NULL : (_tmp28 = (g_object_unref (_tmp28), NULL));
 				(clazz == NULL) ? NULL : (clazz = (vala_code_node_unref (clazz), NULL));
 				(attribute_value_definition == NULL) ? NULL : (attribute_value_definition = (g_object_unref (attribute_value_definition), NULL));
 				(attr == NULL) ? NULL : (attr = (g_object_unref (attr), NULL));
@@ -832,6 +1047,26 @@ GtkamlRootClassDefinition* gtkaml_sax_parser_get_root_definition (GtkamlSAXParse
 }
 
 
+static char* string_substring (const char* self, glong offset, glong len) {
+	glong string_length;
+	const char* start;
+	g_return_val_if_fail (self != NULL, NULL);
+	string_length = g_utf8_strlen (self, -1);
+	if (offset < 0) {
+		offset = string_length + offset;
+		g_return_val_if_fail (offset >= 0, NULL);
+	} else {
+		g_return_val_if_fail (offset <= string_length, NULL);
+	}
+	if (len < 0) {
+		len = string_length - offset;
+	}
+	g_return_val_if_fail ((offset + len) <= string_length, NULL);
+	start = g_utf8_offset_to_pointer (self, offset);
+	return g_strndup (start, ((gchar*) g_utf8_offset_to_pointer (start, len)) - ((gchar*) start));
+}
+
+
 GtkamlClassDefinition* gtkaml_sax_parser_get_child_for_container (GtkamlSAXParser* self, ValaClass* clazz, GtkamlClassDefinition* container_definition, GeeList* attrs, const char* prefix) {
 	char* identifier;
 	DefinitionScope identifier_scope;
