@@ -20,20 +20,74 @@
  *        Vlad Grecescu (b100dian@gmail.com)
  */
 
-#include "GtkamlSimpleAttribute.h"
+#include <glib.h>
+#include <glib-object.h>
+#include <stdlib.h>
+#include <string.h>
 
 
+#define GTKAML_TYPE_ATTRIBUTE (gtkaml_attribute_get_type ())
+#define GTKAML_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_ATTRIBUTE, GtkamlAttribute))
+#define GTKAML_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_ATTRIBUTE, GtkamlAttributeClass))
+#define GTKAML_IS_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_ATTRIBUTE))
+#define GTKAML_IS_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_ATTRIBUTE))
+#define GTKAML_ATTRIBUTE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_ATTRIBUTE, GtkamlAttributeClass))
 
+typedef struct _GtkamlAttribute GtkamlAttribute;
+typedef struct _GtkamlAttributeClass GtkamlAttributeClass;
+typedef struct _GtkamlAttributePrivate GtkamlAttributePrivate;
+
+#define GTKAML_TYPE_SIMPLE_ATTRIBUTE (gtkaml_simple_attribute_get_type ())
+#define GTKAML_SIMPLE_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_SIMPLE_ATTRIBUTE, GtkamlSimpleAttribute))
+#define GTKAML_SIMPLE_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_SIMPLE_ATTRIBUTE, GtkamlSimpleAttributeClass))
+#define GTKAML_IS_SIMPLE_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_SIMPLE_ATTRIBUTE))
+#define GTKAML_IS_SIMPLE_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_SIMPLE_ATTRIBUTE))
+#define GTKAML_SIMPLE_ATTRIBUTE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_SIMPLE_ATTRIBUTE, GtkamlSimpleAttributeClass))
+
+typedef struct _GtkamlSimpleAttribute GtkamlSimpleAttribute;
+typedef struct _GtkamlSimpleAttributeClass GtkamlSimpleAttributeClass;
+typedef struct _GtkamlSimpleAttributePrivate GtkamlSimpleAttributePrivate;
+
+/**
+ * A generic xml attribute with a name and a reflected Vala type
+ */
+struct _GtkamlAttribute {
+	GObject parent_instance;
+	GtkamlAttributePrivate * priv;
+};
+
+struct _GtkamlAttributeClass {
+	GObjectClass parent_class;
+};
+
+struct _GtkamlSimpleAttribute {
+	GtkamlAttribute parent_instance;
+	GtkamlSimpleAttributePrivate * priv;
+};
+
+struct _GtkamlSimpleAttributeClass {
+	GtkamlAttributeClass parent_class;
+};
 
 struct _GtkamlSimpleAttributePrivate {
 	char* _value;
 };
 
+
+
+GType gtkaml_attribute_get_type (void);
+GType gtkaml_simple_attribute_get_type (void);
 #define GTKAML_SIMPLE_ATTRIBUTE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GTKAML_TYPE_SIMPLE_ATTRIBUTE, GtkamlSimpleAttributePrivate))
 enum  {
 	GTKAML_SIMPLE_ATTRIBUTE_DUMMY_PROPERTY,
 	GTKAML_SIMPLE_ATTRIBUTE_VALUE
 };
+void gtkaml_attribute_set_name (GtkamlAttribute* self, const char* value);
+void gtkaml_simple_attribute_set_value (GtkamlSimpleAttribute* self, const char* value);
+GtkamlSimpleAttribute* gtkaml_simple_attribute_new (const char* name, const char* value);
+GtkamlSimpleAttribute* gtkaml_simple_attribute_construct (GType object_type, const char* name, const char* value);
+GtkamlSimpleAttribute* gtkaml_simple_attribute_new (const char* name, const char* value);
+const char* gtkaml_simple_attribute_get_value (GtkamlSimpleAttribute* self);
 static gpointer gtkaml_simple_attribute_parent_class = NULL;
 static void gtkaml_simple_attribute_finalize (GObject* obj);
 
