@@ -20,10 +20,62 @@
  *        Vlad Grecescu (b100dian@gmail.com)
  */
 
-#include "GtkamlState.h"
+#include <glib.h>
+#include <glib-object.h>
+#include <stdlib.h>
+#include <string.h>
 
 
+#define GTKAML_TYPE_STATE_ID (gtkaml_state_id_get_type ())
 
+#define GTKAML_TYPE_STATE (gtkaml_state_get_type ())
+#define GTKAML_STATE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_STATE, GtkamlState))
+#define GTKAML_STATE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_STATE, GtkamlStateClass))
+#define GTKAML_IS_STATE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_STATE))
+#define GTKAML_IS_STATE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_STATE))
+#define GTKAML_STATE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_STATE, GtkamlStateClass))
+
+typedef struct _GtkamlState GtkamlState;
+typedef struct _GtkamlStateClass GtkamlStateClass;
+typedef struct _GtkamlStatePrivate GtkamlStatePrivate;
+
+#define GTKAML_TYPE_CLASS_DEFINITION (gtkaml_class_definition_get_type ())
+#define GTKAML_CLASS_DEFINITION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_CLASS_DEFINITION, GtkamlClassDefinition))
+#define GTKAML_CLASS_DEFINITION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_CLASS_DEFINITION, GtkamlClassDefinitionClass))
+#define GTKAML_IS_CLASS_DEFINITION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_CLASS_DEFINITION))
+#define GTKAML_IS_CLASS_DEFINITION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_CLASS_DEFINITION))
+#define GTKAML_CLASS_DEFINITION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_CLASS_DEFINITION, GtkamlClassDefinitionClass))
+
+typedef struct _GtkamlClassDefinition GtkamlClassDefinition;
+typedef struct _GtkamlClassDefinitionClass GtkamlClassDefinitionClass;
+
+#define GTKAML_TYPE_ATTRIBUTE (gtkaml_attribute_get_type ())
+#define GTKAML_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_ATTRIBUTE, GtkamlAttribute))
+#define GTKAML_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_ATTRIBUTE, GtkamlAttributeClass))
+#define GTKAML_IS_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_ATTRIBUTE))
+#define GTKAML_IS_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_ATTRIBUTE))
+#define GTKAML_ATTRIBUTE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_ATTRIBUTE, GtkamlAttributeClass))
+
+typedef struct _GtkamlAttribute GtkamlAttribute;
+typedef struct _GtkamlAttributeClass GtkamlAttributeClass;
+
+typedef enum  {
+	GTKAML_STATE_ID_SAX_PARSER_INITIAL_STATE = 0,
+	GTKAML_STATE_ID_SAX_PARSER_CONTAINER_STATE,
+	GTKAML_STATE_ID_SAX_PARSER_ATTRIBUTE_STATE
+} GtkamlStateId;
+
+/* here we generate the class declaration, based on current tag, attributes and namespaces 
+ then we can add things to the current container, based on current tag and attributes 
+ the characters are then used as value, string literal - we need the current instance.property */
+struct _GtkamlState {
+	GObject parent_instance;
+	GtkamlStatePrivate * priv;
+};
+
+struct _GtkamlStateClass {
+	GObjectClass parent_class;
+};
 
 struct _GtkamlStatePrivate {
 	GtkamlStateId _state_id;
@@ -32,6 +84,12 @@ struct _GtkamlStatePrivate {
 	char* _attribute_name;
 };
 
+
+
+GType gtkaml_state_id_get_type (void);
+GType gtkaml_state_get_type (void);
+GType gtkaml_class_definition_get_type (void);
+GType gtkaml_attribute_get_type (void);
 #define GTKAML_STATE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GTKAML_TYPE_STATE, GtkamlStatePrivate))
 enum  {
 	GTKAML_STATE_DUMMY_PROPERTY,
@@ -40,6 +98,17 @@ enum  {
 	GTKAML_STATE_ATTRIBUTE,
 	GTKAML_STATE_ATTRIBUTE_NAME
 };
+void gtkaml_state_set_state_id (GtkamlState* self, GtkamlStateId value);
+void gtkaml_state_set_class_definition (GtkamlState* self, GtkamlClassDefinition* value);
+void gtkaml_state_set_attribute (GtkamlState* self, GtkamlAttribute* value);
+void gtkaml_state_set_attribute_name (GtkamlState* self, const char* value);
+GtkamlState* gtkaml_state_new (GtkamlStateId state_id, GtkamlClassDefinition* class_definition, GtkamlAttribute* attribute, const char* attribute_name);
+GtkamlState* gtkaml_state_construct (GType object_type, GtkamlStateId state_id, GtkamlClassDefinition* class_definition, GtkamlAttribute* attribute, const char* attribute_name);
+GtkamlState* gtkaml_state_new (GtkamlStateId state_id, GtkamlClassDefinition* class_definition, GtkamlAttribute* attribute, const char* attribute_name);
+GtkamlStateId gtkaml_state_get_state_id (GtkamlState* self);
+GtkamlClassDefinition* gtkaml_state_get_class_definition (GtkamlState* self);
+GtkamlAttribute* gtkaml_state_get_attribute (GtkamlState* self);
+const char* gtkaml_state_get_attribute_name (GtkamlState* self);
 static gpointer gtkaml_state_parent_class = NULL;
 static void gtkaml_state_finalize (GObject* obj);
 
