@@ -20,23 +20,63 @@
  *        Vlad Grecescu (b100dian@gmail.com)
  */
 
-#include "GtkamlStateStack.h"
-#include <gee/arraylist.h>
-#include <gee/collection.h>
-#include <gee/list.h>
+#include <glib.h>
+#include <glib-object.h>
+#include <gee.h>
 
 
+#define GTKAML_TYPE_STATE_STACK (gtkaml_state_stack_get_type ())
+#define GTKAML_STATE_STACK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_STATE_STACK, GtkamlStateStack))
+#define GTKAML_STATE_STACK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_STATE_STACK, GtkamlStateStackClass))
+#define GTKAML_IS_STATE_STACK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_STATE_STACK))
+#define GTKAML_IS_STATE_STACK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_STATE_STACK))
+#define GTKAML_STATE_STACK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_STATE_STACK, GtkamlStateStackClass))
 
+typedef struct _GtkamlStateStack GtkamlStateStack;
+typedef struct _GtkamlStateStackClass GtkamlStateStackClass;
+typedef struct _GtkamlStateStackPrivate GtkamlStateStackPrivate;
+
+#define GTKAML_TYPE_STATE (gtkaml_state_get_type ())
+#define GTKAML_STATE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_STATE, GtkamlState))
+#define GTKAML_STATE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_STATE, GtkamlStateClass))
+#define GTKAML_IS_STATE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_STATE))
+#define GTKAML_IS_STATE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_STATE))
+#define GTKAML_STATE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_STATE, GtkamlStateClass))
+
+typedef struct _GtkamlState GtkamlState;
+typedef struct _GtkamlStateClass GtkamlStateClass;
+
+/** 
+ * Simple, specialized, stack implementation using a Gee.List
+ */
+struct _GtkamlStateStack {
+	GObject parent_instance;
+	GtkamlStateStackPrivate * priv;
+};
+
+struct _GtkamlStateStackClass {
+	GObjectClass parent_class;
+};
 
 struct _GtkamlStateStackPrivate {
 	GeeArrayList* _array_list;
 };
 
+
+
+GType gtkaml_state_stack_get_type (void);
+GType gtkaml_state_get_type (void);
 #define GTKAML_STATE_STACK_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GTKAML_TYPE_STATE_STACK, GtkamlStateStackPrivate))
 enum  {
 	GTKAML_STATE_STACK_DUMMY_PROPERTY
 };
 static GeeArrayList* gtkaml_state_stack_get_array_list (GtkamlStateStack* self);
+void gtkaml_state_stack_push (GtkamlStateStack* self, GtkamlState* element);
+GtkamlState* gtkaml_state_stack_peek (GtkamlStateStack* self, gint backtrack);
+GtkamlState* gtkaml_state_stack_pop (GtkamlStateStack* self);
+GtkamlStateStack* gtkaml_state_stack_new (void);
+GtkamlStateStack* gtkaml_state_stack_construct (GType object_type);
+GtkamlStateStack* gtkaml_state_stack_new (void);
 static void gtkaml_state_stack_set_array_list (GtkamlStateStack* self, GeeArrayList* value);
 static GObject * gtkaml_state_stack_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer gtkaml_state_stack_parent_class = NULL;
