@@ -20,14 +20,48 @@
  *        Vlad Grecescu (b100dian@gmail.com)
  */
 
-#include "GtkamlXmlAttribute.h"
+#include <glib.h>
+#include <glib-object.h>
+#include <stdlib.h>
+#include <string.h>
 
 
+#define GTKAML_TYPE_XML_ATTRIBUTE (gtkaml_xml_attribute_get_type ())
+#define GTKAML_XML_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_XML_ATTRIBUTE, GtkamlXmlAttribute))
+#define GTKAML_XML_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_XML_ATTRIBUTE, GtkamlXmlAttributeClass))
+#define GTKAML_IS_XML_ATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_XML_ATTRIBUTE))
+#define GTKAML_IS_XML_ATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_XML_ATTRIBUTE))
+#define GTKAML_XML_ATTRIBUTE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_XML_ATTRIBUTE, GtkamlXmlAttributeClass))
+
+typedef struct _GtkamlXmlAttribute GtkamlXmlAttribute;
+typedef struct _GtkamlXmlAttributeClass GtkamlXmlAttributeClass;
+typedef struct _GtkamlXmlAttributePrivate GtkamlXmlAttributePrivate;
+
+/**
+ * an attribute as presented by libxml2
+ */
+struct _GtkamlXmlAttribute {
+	GObject parent_instance;
+	GtkamlXmlAttributePrivate * priv;
+	char* localname;
+	char* prefix;
+	char* URI;
+	char* value;
+};
+
+struct _GtkamlXmlAttributeClass {
+	GObjectClass parent_class;
+};
+
 
 
+GType gtkaml_xml_attribute_get_type (void);
 enum  {
 	GTKAML_XML_ATTRIBUTE_DUMMY_PROPERTY
 };
+GtkamlXmlAttribute* gtkaml_xml_attribute_new (void);
+GtkamlXmlAttribute* gtkaml_xml_attribute_construct (GType object_type);
+GtkamlXmlAttribute* gtkaml_xml_attribute_new (void);
 static gpointer gtkaml_xml_attribute_parent_class = NULL;
 static void gtkaml_xml_attribute_finalize (GObject* obj);
 
