@@ -20,14 +20,46 @@
  *        Vlad Grecescu (b100dian@gmail.com)
  */
 
-#include "GtkamlXmlNamespace.h"
+#include <glib.h>
+#include <glib-object.h>
+#include <stdlib.h>
+#include <string.h>
 
 
+#define TYPE_XML_NAMESPACE (xml_namespace_get_type ())
+#define XML_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_XML_NAMESPACE, XmlNamespace))
+#define XML_NAMESPACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_XML_NAMESPACE, XmlNamespaceClass))
+#define IS_XML_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_XML_NAMESPACE))
+#define IS_XML_NAMESPACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_XML_NAMESPACE))
+#define XML_NAMESPACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_XML_NAMESPACE, XmlNamespaceClass))
+
+typedef struct _XmlNamespace XmlNamespace;
+typedef struct _XmlNamespaceClass XmlNamespaceClass;
+typedef struct _XmlNamespacePrivate XmlNamespacePrivate;
+
+/**
+ * an xml namespace, often referred to as 'prefix'
+ */
+struct _XmlNamespace {
+	GObject parent_instance;
+	XmlNamespacePrivate * priv;
+	char* prefix;
+	char* URI;
+};
+
+struct _XmlNamespaceClass {
+	GObjectClass parent_class;
+};
+
 
 
+GType xml_namespace_get_type (void);
 enum  {
 	XML_NAMESPACE_DUMMY_PROPERTY
 };
+XmlNamespace* xml_namespace_new (void);
+XmlNamespace* xml_namespace_construct (GType object_type);
+XmlNamespace* xml_namespace_new (void);
 static gpointer xml_namespace_parent_class = NULL;
 static void xml_namespace_finalize (GObject* obj);
 
